from cloudera.ai.inference.api.serving_api import ServingApi
from cloudera.ai.inference.api_client import ApiClient
from cloudera.ai.inference.configuration import Configuration


def create_client(host: str, token: str, *, verify_ssl: bool = True) -> ServingApi:
    """Create an authenticated ServingApi client.

    Args:
        host: The service domain, e.g. "https://ml-abc123.example.com"
        token: Token for authentication
        verify_ssl: Whether to verify SSL certificates. Default True.

    Returns:
        An authenticated ServingApi instance ready to use.

    Example::

        from cloudera.ai.inference import create_client

        client = create_client(
            host="https://ml-abc123.example.com",
            token="<cdp-token>",
        )
        response = client.serving_list_endpoints(...)
    """
    config = Configuration(host=host)
    config.verify_ssl = verify_ssl
    return ServingApi(
        ApiClient(
            configuration=config,
            header_name="Authorization",
            header_value=f"Bearer {token}",
        )
    )



# coding: utf-8

"""
    Cloudera AI Inference

    CML Serving :: Install and manage CML Serving workloads.

    The version of the OpenAPI document: v1alpha1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from cloudera.ai.inference.models.serving_application_revision import ServingApplicationRevision
from cloudera.ai.inference.models.serving_autoscaling import ServingAutoscaling
from cloudera.ai.inference.models.serving_condition import ServingCondition
from cloudera.ai.inference.models.serving_relevant_revisions_meta import ServingRelevantRevisionsMeta
from cloudera.ai.inference.models.serving_resources import ServingResources
from typing import Optional, Set
from typing_extensions import Self

class ServingDescribeApplicationResponse(BaseModel):
    """
    ServingDescribeApplicationResponse
    """ # noqa: E501
    namespace: Optional[StrictStr] = None
    name: Optional[StrictStr] = None
    url: Optional[StrictStr] = None
    conditions: Optional[List[ServingCondition]] = None
    subdomain: Optional[StrictStr] = None
    observed_generation: Optional[StrictInt] = None
    created_by: Optional[StrictStr] = None
    description: Optional[StrictStr] = None
    created_at: Optional[datetime] = None
    resources: Optional[ServingResources] = None
    revisions: Optional[List[ServingApplicationRevision]] = None
    relevant_revisions: Optional[ServingRelevantRevisionsMeta] = None
    autoscaling: Optional[ServingAutoscaling] = None
    state: Optional[StrictStr] = None
    last_updated_at: Optional[datetime] = None
    is_web_app: Optional[StrictBool] = None
    source_url: Optional[StrictStr] = Field(default=None, description="The URL of the application source (container or directory)")
    __properties: ClassVar[List[str]] = ["namespace", "name", "url", "conditions", "subdomain", "observed_generation", "created_by", "description", "created_at", "resources", "revisions", "relevant_revisions", "autoscaling", "state", "last_updated_at", "is_web_app", "source_url"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ServingDescribeApplicationResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in conditions (list)
        _items = []
        if self.conditions:
            for _item_conditions in self.conditions:
                if _item_conditions:
                    _items.append(_item_conditions.to_dict())
            _dict['conditions'] = _items
        # override the default output from pydantic by calling `to_dict()` of resources
        if self.resources:
            _dict['resources'] = self.resources.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in revisions (list)
        _items = []
        if self.revisions:
            for _item_revisions in self.revisions:
                if _item_revisions:
                    _items.append(_item_revisions.to_dict())
            _dict['revisions'] = _items
        # override the default output from pydantic by calling `to_dict()` of relevant_revisions
        if self.relevant_revisions:
            _dict['relevant_revisions'] = self.relevant_revisions.to_dict()
        # override the default output from pydantic by calling `to_dict()` of autoscaling
        if self.autoscaling:
            _dict['autoscaling'] = self.autoscaling.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ServingDescribeApplicationResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "namespace": obj.get("namespace"),
            "name": obj.get("name"),
            "url": obj.get("url"),
            "conditions": [ServingCondition.from_dict(_item) for _item in obj["conditions"]] if obj.get("conditions") is not None else None,
            "subdomain": obj.get("subdomain"),
            "observed_generation": obj.get("observed_generation"),
            "created_by": obj.get("created_by"),
            "description": obj.get("description"),
            "created_at": obj.get("created_at"),
            "resources": ServingResources.from_dict(obj["resources"]) if obj.get("resources") is not None else None,
            "revisions": [ServingApplicationRevision.from_dict(_item) for _item in obj["revisions"]] if obj.get("revisions") is not None else None,
            "relevant_revisions": ServingRelevantRevisionsMeta.from_dict(obj["relevant_revisions"]) if obj.get("relevant_revisions") is not None else None,
            "autoscaling": ServingAutoscaling.from_dict(obj["autoscaling"]) if obj.get("autoscaling") is not None else None,
            "state": obj.get("state"),
            "last_updated_at": obj.get("last_updated_at"),
            "is_web_app": obj.get("is_web_app"),
            "source_url": obj.get("source_url")
        })
        return _obj





# coding: utf-8

"""
    Cloudera AI Inference

    CML Serving :: Install and manage CML Serving workloads.

    The version of the OpenAPI document: v1alpha1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from cloudera.ai.inference.models.serving_autoscaling import ServingAutoscaling
from cloudera.ai.inference.models.serving_condition import ServingCondition
from cloudera.ai.inference.models.serving_environment_variable import ServingEnvironmentVariable
from cloudera.ai.inference.models.serving_inference_logging_config import ServingInferenceLoggingConfig
from cloudera.ai.inference.models.serving_label import ServingLabel
from cloudera.ai.inference.models.serving_model_revision import ServingModelRevision
from cloudera.ai.inference.models.serving_model_status import ServingModelStatus
from cloudera.ai.inference.models.serving_optimization_profile import ServingOptimizationProfile
from cloudera.ai.inference.models.serving_rate_limit_config import ServingRateLimitConfig
from cloudera.ai.inference.models.serving_relevant_revisions_meta import ServingRelevantRevisionsMeta
from cloudera.ai.inference.models.serving_resources import ServingResources
from cloudera.ai.inference.models.serving_runtime_info import ServingRuntimeInfo
from cloudera.ai.inference.models.serving_traffic import ServingTraffic
from typing import Optional, Set
from typing_extensions import Self

class ServingDescribeEndpointResponse(BaseModel):
    """
    ServingDescribeEndpointResponse
    """ # noqa: E501
    namespace: Optional[StrictStr] = None
    name: Optional[StrictStr] = None
    url: Optional[StrictStr] = None
    conditions: Optional[List[ServingCondition]] = None
    status: Optional[ServingModelStatus] = None
    observed_generation: Optional[StrictInt] = None
    replica_count: Optional[StrictInt] = None
    created_by: Optional[StrictStr] = None
    description: Optional[StrictStr] = None
    created_at: Optional[datetime] = None
    resources: Optional[ServingResources] = None
    revisions: Optional[List[ServingModelRevision]] = None
    autoscaling: Optional[ServingAutoscaling] = None
    relevant_revisions: Optional[ServingRelevantRevisionsMeta] = None
    model_name: Optional[StrictStr] = None
    traffic: Optional[ServingTraffic] = None
    api_standard: Optional[StrictStr] = None
    has_chat_template: Optional[StrictBool] = None
    metric_format: Optional[StrictStr] = None
    task: Optional[StrictStr] = None
    instance_type: Optional[StrictStr] = None
    optimization_profile: Optional[ServingOptimizationProfile] = None
    crn: Optional[StrictStr] = None
    inference_logging_config: Optional[ServingInferenceLoggingConfig] = None
    runtime_info: Optional[ServingRuntimeInfo] = None
    vllm_args: Optional[StrictStr] = None
    deployment_mode: Optional[StrictStr] = None
    environment_variables: Optional[List[ServingEnvironmentVariable]] = None
    gpu_type: Optional[StrictStr] = Field(default=None, alias="gpuType")
    tags: Optional[List[ServingLabel]] = None
    rate_limit: Optional[ServingRateLimitConfig] = Field(default=None, description="current rate limit configuration for this endpoint")
    state: Optional[StrictStr] = Field(default=None, description="unified state field that matches listEndpoints response for consistency")
    __properties: ClassVar[List[str]] = ["namespace", "name", "url", "conditions", "status", "observed_generation", "replica_count", "created_by", "description", "created_at", "resources", "revisions", "autoscaling", "relevant_revisions", "model_name", "traffic", "api_standard", "has_chat_template", "metric_format", "task", "instance_type", "optimization_profile", "crn", "inference_logging_config", "runtime_info", "vllm_args", "deployment_mode", "environment_variables", "gpuType", "tags", "rate_limit", "state"]

    @field_validator('deployment_mode')
    def deployment_mode_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['DEPLOYMENT_MODE_UNKNOWN', 'KNATIVE', 'RAW_DEPLOYMENT']):
            raise ValueError("must be one of enum values ('DEPLOYMENT_MODE_UNKNOWN', 'KNATIVE', 'RAW_DEPLOYMENT')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ServingDescribeEndpointResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in conditions (list)
        _items = []
        if self.conditions:
            for _item_conditions in self.conditions:
                if _item_conditions:
                    _items.append(_item_conditions.to_dict())
            _dict['conditions'] = _items
        # override the default output from pydantic by calling `to_dict()` of status
        if self.status:
            _dict['status'] = self.status.to_dict()
        # override the default output from pydantic by calling `to_dict()` of resources
        if self.resources:
            _dict['resources'] = self.resources.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in revisions (list)
        _items = []
        if self.revisions:
            for _item_revisions in self.revisions:
                if _item_revisions:
                    _items.append(_item_revisions.to_dict())
            _dict['revisions'] = _items
        # override the default output from pydantic by calling `to_dict()` of autoscaling
        if self.autoscaling:
            _dict['autoscaling'] = self.autoscaling.to_dict()
        # override the default output from pydantic by calling `to_dict()` of relevant_revisions
        if self.relevant_revisions:
            _dict['relevant_revisions'] = self.relevant_revisions.to_dict()
        # override the default output from pydantic by calling `to_dict()` of traffic
        if self.traffic:
            _dict['traffic'] = self.traffic.to_dict()
        # override the default output from pydantic by calling `to_dict()` of optimization_profile
        if self.optimization_profile:
            _dict['optimization_profile'] = self.optimization_profile.to_dict()
        # override the default output from pydantic by calling `to_dict()` of inference_logging_config
        if self.inference_logging_config:
            _dict['inference_logging_config'] = self.inference_logging_config.to_dict()
        # override the default output from pydantic by calling `to_dict()` of runtime_info
        if self.runtime_info:
            _dict['runtime_info'] = self.runtime_info.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in environment_variables (list)
        _items = []
        if self.environment_variables:
            for _item_environment_variables in self.environment_variables:
                if _item_environment_variables:
                    _items.append(_item_environment_variables.to_dict())
            _dict['environment_variables'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in tags (list)
        _items = []
        if self.tags:
            for _item_tags in self.tags:
                if _item_tags:
                    _items.append(_item_tags.to_dict())
            _dict['tags'] = _items
        # override the default output from pydantic by calling `to_dict()` of rate_limit
        if self.rate_limit:
            _dict['rate_limit'] = self.rate_limit.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ServingDescribeEndpointResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "namespace": obj.get("namespace"),
            "name": obj.get("name"),
            "url": obj.get("url"),
            "conditions": [ServingCondition.from_dict(_item) for _item in obj["conditions"]] if obj.get("conditions") is not None else None,
            "status": ServingModelStatus.from_dict(obj["status"]) if obj.get("status") is not None else None,
            "observed_generation": obj.get("observed_generation"),
            "replica_count": obj.get("replica_count"),
            "created_by": obj.get("created_by"),
            "description": obj.get("description"),
            "created_at": obj.get("created_at"),
            "resources": ServingResources.from_dict(obj["resources"]) if obj.get("resources") is not None else None,
            "revisions": [ServingModelRevision.from_dict(_item) for _item in obj["revisions"]] if obj.get("revisions") is not None else None,
            "autoscaling": ServingAutoscaling.from_dict(obj["autoscaling"]) if obj.get("autoscaling") is not None else None,
            "relevant_revisions": ServingRelevantRevisionsMeta.from_dict(obj["relevant_revisions"]) if obj.get("relevant_revisions") is not None else None,
            "model_name": obj.get("model_name"),
            "traffic": ServingTraffic.from_dict(obj["traffic"]) if obj.get("traffic") is not None else None,
            "api_standard": obj.get("api_standard"),
            "has_chat_template": obj.get("has_chat_template"),
            "metric_format": obj.get("metric_format"),
            "task": obj.get("task"),
            "instance_type": obj.get("instance_type"),
            "optimization_profile": ServingOptimizationProfile.from_dict(obj["optimization_profile"]) if obj.get("optimization_profile") is not None else None,
            "crn": obj.get("crn"),
            "inference_logging_config": ServingInferenceLoggingConfig.from_dict(obj["inference_logging_config"]) if obj.get("inference_logging_config") is not None else None,
            "runtime_info": ServingRuntimeInfo.from_dict(obj["runtime_info"]) if obj.get("runtime_info") is not None else None,
            "vllm_args": obj.get("vllm_args"),
            "deployment_mode": obj.get("deployment_mode"),
            "environment_variables": [ServingEnvironmentVariable.from_dict(_item) for _item in obj["environment_variables"]] if obj.get("environment_variables") is not None else None,
            "gpuType": obj.get("gpuType"),
            "tags": [ServingLabel.from_dict(_item) for _item in obj["tags"]] if obj.get("tags") is not None else None,
            "rate_limit": ServingRateLimitConfig.from_dict(obj["rate_limit"]) if obj.get("rate_limit") is not None else None,
            "state": obj.get("state")
        })
        return _obj





# coding: utf-8

"""
    Cloudera AI Inference

    CML Serving :: Install and manage CML Serving workloads.

    The version of the OpenAPI document: v1alpha1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from cloudera.ai.inference.models.serving_third_party_source import ServingThirdPartySource

class TestServingThirdPartySource(unittest.TestCase):
    """ServingThirdPartySource unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ServingThirdPartySource:
        """Test ServingThirdPartySource
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ServingThirdPartySource`
        """
        model = ServingThirdPartySource()
        if include_optional:
            return ServingThirdPartySource(
                url = '',
                model = '',
                provider_type = 'THIRD_PARTY_PROVIDER_UNSPECIFIED',
                api_key = '',
                aws_credentials = cloudera.ai.inference.models.serving/aws_credentials.serving.AWSCredentials(
                    access_key_id = '', 
                    secret_access_key = '', 
                    region = '', 
                    bearer_token = '', ),
                gcp_credentials = cloudera.ai.inference.models.serving/gcp_credentials.serving.GCPCredentials(
                    service_account_json = '', 
                    project_name = '', 
                    region = '', ),
                api_version = '',
                path_prefix = ''
            )
        else:
            return ServingThirdPartySource(
        )
        """

    def testServingThirdPartySource(self):
        """Test ServingThirdPartySource"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Cloudera AI Inference

    CML Serving :: Install and manage CML Serving workloads.

    The version of the OpenAPI document: v1alpha1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from cloudera.ai.inference.models.serving_describe_service_response import ServingDescribeServiceResponse

class TestServingDescribeServiceResponse(unittest.TestCase):
    """ServingDescribeServiceResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ServingDescribeServiceResponse:
        """Test ServingDescribeServiceResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ServingDescribeServiceResponse`
        """
        model = ServingDescribeServiceResponse()
        if include_optional:
            return ServingDescribeServiceResponse(
                crn = '',
                version = '',
                features = cloudera.ai.inference.models.serving/features_status.serving.FeaturesStatus(
                    fine_grained_authorization = True, 
                    payload_logging = True, ),
                api_versions = [
                    ''
                    ],
                runtimes = [
                    cloudera.ai.inference.models.serving/runtime_info.serving.RuntimeInfo(
                        display_name = '', 
                        version = '', 
                        image_identifier = '', 
                        vllm_version = '', 
                        transformers_library_version = '', 
                        latest_version = True, 
                        runtime_name = '', )
                    ],
                inference_logging_config = cloudera.ai.inference.models.serving/inference_logging_config.serving.InferenceLoggingConfig(
                    enabled = True, 
                    explainer_s3_config = cloudera.ai.inference.models.serving/s3_inference_logging_config.serving.S3InferenceLoggingConfig(
                        bucket_url = '', 
                        access_key_id = '', 
                        secret_access_key = '', 
                        region = '', ), 
                    explainer_abs_config = cloudera.ai.inference.models.serving/abs_inference_logging_config.serving.ABSInferenceLoggingConfig(
                        bucket_url = '', 
                        client_id = '', 
                        client_secret = '', 
                        tenant_id = '', 
                        subscription_id = '', 
                        access_token = '', 
                        access_token_expiration_seconds = 56, 
                        service_url = '', ), 
                    explainer_gcs_config = cloudera.ai.inference.models.serving/gcs_inference_logging_config.serving.GCSInferenceLoggingConfig(
                        bucket_url = '', 
                        key_file = '', ), 
                    explainer_datalake_config = cloudera.ai.inference.models.serving/data_lake_logging_config.serving.DataLakeLoggingConfig(
                        datalake_crn = '', 
                        path = '', 
                        resolved_storage_url = '', ), 
                    predictor_s3_config = cloudera.ai.inference.models.serving/s3_inference_logging_config.serving.S3InferenceLoggingConfig(
                        bucket_url = '', 
                        access_key_id = '', 
                        secret_access_key = '', 
                        region = '', ), 
                    predictor_abs_config = cloudera.ai.inference.models.serving/abs_inference_logging_config.serving.ABSInferenceLoggingConfig(
                        bucket_url = '', 
                        client_id = '', 
                        client_secret = '', 
                        tenant_id = '', 
                        subscription_id = '', 
                        access_token = '', 
                        access_token_expiration_seconds = 56, 
                        service_url = '', ), 
                    predictor_gcs_config = cloudera.ai.inference.models.serving/gcs_inference_logging_config.serving.GCSInferenceLoggingConfig(
                        bucket_url = '', 
                        key_file = '', ), 
                    predictor_datalake_config = cloudera.ai.inference.models.serving/data_lake_logging_config.serving.DataLakeLoggingConfig(
                        datalake_crn = '', 
                        path = '', 
                        resolved_storage_url = '', ), 
                    transformer_s3_config = , 
                    transformer_abs_config = , 
                    transformer_gcs_config = , 
                    transformer_datalake_config = , 
                    format = 'LOGGING_FORMAT_UNKNOWN', 
                    batch_size = 56, 
                    rollover_frequency = 'ROLLOVER_FREQUENCY_UNKNOWN', )
            )
        else:
            return ServingDescribeServiceResponse(
        )
        """

    def testServingDescribeServiceResponse(self):
        """Test ServingDescribeServiceResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Cloudera AI Inference

    CML Serving :: Install and manage CML Serving workloads.

    The version of the OpenAPI document: v1alpha1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from cloudera.ai.inference.models.serving_autoscaling import ServingAutoscaling
from cloudera.ai.inference.models.serving_environment_variable import ServingEnvironmentVariable
from cloudera.ai.inference.models.serving_inference_logging_config import ServingInferenceLoggingConfig
from cloudera.ai.inference.models.serving_label import ServingLabel
from cloudera.ai.inference.models.serving_model_source import ServingModelSource
from cloudera.ai.inference.models.serving_rate_limit_config import ServingRateLimitConfig
from cloudera.ai.inference.models.serving_resources import ServingResources
from cloudera.ai.inference.models.serving_vllm_engine_args import ServingVLLMEngineArgs
from typing import Optional, Set
from typing_extensions import Self

class ServingDeployEndpointRequest(BaseModel):
    """
    ServingDeployEndpointRequest
    """ # noqa: E501
    namespace: Optional[StrictStr] = Field(default=None, description="the namespace that the endpoint resides in")
    name: Optional[StrictStr] = Field(default=None, description="the name of the endpoint.  Can consist of alphanumerics, spaces, dashes but must not exceed 36 characters")
    source: Optional[ServingModelSource] = Field(default=None, description="the source of the endpoint")
    resources: Optional[ServingResources] = Field(default=None, description="the resource requirements for the given endpoint replica")
    autoscaling: Optional[ServingAutoscaling] = Field(default=None, description="the autoscaling configurations for the given endpoint")
    labels: Optional[List[ServingLabel]] = Field(default=None, description="labels to be added to the given endpoint")
    description: Optional[StrictStr] = Field(default=None, description="a description of the endpoint")
    traffic: Optional[StrictStr] = Field(default=None, description="the traffic routed to this revision.  This is always set to 100 for endpoint deployments")
    vllm_engine_args: Optional[ServingVLLMEngineArgs] = Field(default=None, description="DEPRECATED (use vllm_args instead): arguments specifically passed into vLLM models")
    instance_type: Optional[StrictStr] = Field(default=None, description="the compute instance type that the model deployment should be scheduled on")
    gpu_type: Optional[StrictStr] = Field(default=None, description="the gpu type, eg A100", alias="gpuType")
    inference_logging_config: Optional[ServingInferenceLoggingConfig] = Field(default=None, description="inference logging configuration to apply to the endpoint")
    ml_user_permission: Optional[StrictStr] = Field(default=None, description="permission to be granted to the mluser group")
    vllm_args: Optional[StrictStr] = Field(default=None, description="arguments specifically passed into vLLM models")
    deployment_mode: Optional[StrictStr] = Field(default=None, description="deployment mode.  Default is KNATIVE")
    environment_variables: Optional[List[ServingEnvironmentVariable]] = Field(default=None, description="environment variables to be added to the endpoint")
    task_override: Optional[StrictStr] = Field(default=None, description="optional task override to specify model task when auto-detection is ambiguous or incorrect")
    rate_limit: Optional[ServingRateLimitConfig] = Field(default=None, description="optional rate limit configuration for the endpoint")
    __properties: ClassVar[List[str]] = ["namespace", "name", "source", "resources", "autoscaling", "labels", "description", "traffic", "vllm_engine_args", "instance_type", "gpuType", "inference_logging_config", "ml_user_permission", "vllm_args", "deployment_mode", "environment_variables", "task_override", "rate_limit"]

    @field_validator('deployment_mode')
    def deployment_mode_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['DEPLOYMENT_MODE_UNKNOWN', 'KNATIVE', 'RAW_DEPLOYMENT']):
            raise ValueError("must be one of enum values ('DEPLOYMENT_MODE_UNKNOWN', 'KNATIVE', 'RAW_DEPLOYMENT')")
        return value

    @field_validator('task_override')
    def task_override_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['TASK_UNKNOWN', 'INFERENCE', 'TEXT_GENERATION', 'EMBED', 'TEXT_TO_TEXT_GENERATION', 'CLASSIFICATION', 'FILL_MASK', 'RANK', 'SPEECH_TO_TEXT', 'IMAGE_TEXT_TO_TEXT', 'OBJECT_DETECTION', 'TEXT_TO_SPEECH']):
            raise ValueError("must be one of enum values ('TASK_UNKNOWN', 'INFERENCE', 'TEXT_GENERATION', 'EMBED', 'TEXT_TO_TEXT_GENERATION', 'CLASSIFICATION', 'FILL_MASK', 'RANK', 'SPEECH_TO_TEXT', 'IMAGE_TEXT_TO_TEXT', 'OBJECT_DETECTION', 'TEXT_TO_SPEECH')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ServingDeployEndpointRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of source
        if self.source:
            _dict['source'] = self.source.to_dict()
        # override the default output from pydantic by calling `to_dict()` of resources
        if self.resources:
            _dict['resources'] = self.resources.to_dict()
        # override the default output from pydantic by calling `to_dict()` of autoscaling
        if self.autoscaling:
            _dict['autoscaling'] = self.autoscaling.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in labels (list)
        _items = []
        if self.labels:
            for _item_labels in self.labels:
                if _item_labels:
                    _items.append(_item_labels.to_dict())
            _dict['labels'] = _items
        # override the default output from pydantic by calling `to_dict()` of vllm_engine_args
        if self.vllm_engine_args:
            _dict['vllm_engine_args'] = self.vllm_engine_args.to_dict()
        # override the default output from pydantic by calling `to_dict()` of inference_logging_config
        if self.inference_logging_config:
            _dict['inference_logging_config'] = self.inference_logging_config.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in environment_variables (list)
        _items = []
        if self.environment_variables:
            for _item_environment_variables in self.environment_variables:
                if _item_environment_variables:
                    _items.append(_item_environment_variables.to_dict())
            _dict['environment_variables'] = _items
        # override the default output from pydantic by calling `to_dict()` of rate_limit
        if self.rate_limit:
            _dict['rate_limit'] = self.rate_limit.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ServingDeployEndpointRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "namespace": obj.get("namespace"),
            "name": obj.get("name"),
            "source": ServingModelSource.from_dict(obj["source"]) if obj.get("source") is not None else None,
            "resources": ServingResources.from_dict(obj["resources"]) if obj.get("resources") is not None else None,
            "autoscaling": ServingAutoscaling.from_dict(obj["autoscaling"]) if obj.get("autoscaling") is not None else None,
            "labels": [ServingLabel.from_dict(_item) for _item in obj["labels"]] if obj.get("labels") is not None else None,
            "description": obj.get("description"),
            "traffic": obj.get("traffic"),
            "vllm_engine_args": ServingVLLMEngineArgs.from_dict(obj["vllm_engine_args"]) if obj.get("vllm_engine_args") is not None else None,
            "instance_type": obj.get("instance_type"),
            "gpuType": obj.get("gpuType"),
            "inference_logging_config": ServingInferenceLoggingConfig.from_dict(obj["inference_logging_config"]) if obj.get("inference_logging_config") is not None else None,
            "ml_user_permission": obj.get("ml_user_permission"),
            "vllm_args": obj.get("vllm_args"),
            "deployment_mode": obj.get("deployment_mode"),
            "environment_variables": [ServingEnvironmentVariable.from_dict(_item) for _item in obj["environment_variables"]] if obj.get("environment_variables") is not None else None,
            "task_override": obj.get("task_override"),
            "rate_limit": ServingRateLimitConfig.from_dict(obj["rate_limit"]) if obj.get("rate_limit") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Cloudera AI Inference

    CML Serving :: Install and manage CML Serving workloads.

    The version of the OpenAPI document: v1alpha1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from cloudera.ai.inference.models.archiver_cluster_log_archive_metadata import ArchiverClusterLogArchiveMetadata

class TestArchiverClusterLogArchiveMetadata(unittest.TestCase):
    """ArchiverClusterLogArchiveMetadata unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ArchiverClusterLogArchiveMetadata:
        """Test ArchiverClusterLogArchiveMetadata
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ArchiverClusterLogArchiveMetadata`
        """
        model = ArchiverClusterLogArchiveMetadata()
        if include_optional:
            return ArchiverClusterLogArchiveMetadata(
                archive_id = '',
                request = cloudera.ai.inference.models.archiver/create_cluster_log_archive_request.archiver.CreateClusterLogArchiveRequest(
                    uuid = '', 
                    timespan_minutes = 56, 
                    include_endpoints = True, 
                    redact_sensitive_data = True, 
                    send_to_cloudera = True, 
                    case_number = '', 
                    include_applications = True, ),
                requested_time = '',
                status = 'QUEUED',
                bytes = ''
            )
        else:
            return ArchiverClusterLogArchiveMetadata(
        )
        """

    def testArchiverClusterLogArchiveMetadata(self):
        """Test ArchiverClusterLogArchiveMetadata"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Cloudera AI Inference

    CML Serving :: Install and manage CML Serving workloads.

    The version of the OpenAPI document: v1alpha1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from cloudera.ai.inference.models.serving_describe_service_health_response import ServingDescribeServiceHealthResponse

class TestServingDescribeServiceHealthResponse(unittest.TestCase):
    """ServingDescribeServiceHealthResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ServingDescribeServiceHealthResponse:
        """Test ServingDescribeServiceHealthResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ServingDescribeServiceHealthResponse`
        """
        model = ServingDescribeServiceHealthResponse()
        if include_optional:
            return ServingDescribeServiceHealthResponse(
                cml_serving_api = cloudera.ai.inference.models.serving/service_status.serving.ServiceStatus(
                    healthy = True, 
                    description = '', 
                    last_updated_at = '', ),
                kubernetes = cloudera.ai.inference.models.serving/service_status.serving.ServiceStatus(
                    healthy = True, 
                    description = '', 
                    last_updated_at = '', ),
                knative = cloudera.ai.inference.models.serving/service_status.serving.ServiceStatus(
                    healthy = True, 
                    description = '', 
                    last_updated_at = '', ),
                kserve = cloudera.ai.inference.models.serving/service_status.serving.ServiceStatus(
                    healthy = True, 
                    description = '', 
                    last_updated_at = '', ),
                istio = cloudera.ai.inference.models.serving/service_status.serving.ServiceStatus(
                    healthy = True, 
                    description = '', 
                    last_updated_at = '', ),
                cml_registry = cloudera.ai.inference.models.serving/service_status.serving.ServiceStatus(
                    healthy = True, 
                    description = '', 
                    last_updated_at = '', ),
                cml_client = cloudera.ai.inference.models.serving/service_status.serving.ServiceStatus(
                    healthy = True, 
                    description = '', 
                    last_updated_at = '', ),
                archiver_client = cloudera.ai.inference.models.serving/service_status.serving.ServiceStatus(
                    healthy = True, 
                    description = '', 
                    last_updated_at = '', ),
                usage_reporter_client = cloudera.ai.inference.models.serving/service_status.serving.ServiceStatus(
                    healthy = True, 
                    description = '', 
                    last_updated_at = '', ),
                authorizer_client = cloudera.ai.inference.models.serving/service_status.serving.ServiceStatus(
                    healthy = True, 
                    description = '', 
                    last_updated_at = '', )
            )
        else:
            return ServingDescribeServiceHealthResponse(
        )
        """

    def testServingDescribeServiceHealthResponse(self):
        """Test ServingDescribeServiceHealthResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Cloudera AI Inference

    CML Serving :: Install and manage CML Serving workloads.

    The version of the OpenAPI document: v1alpha1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from cloudera.ai.inference.models.serving_deploy_application_request import ServingDeployApplicationRequest

class TestServingDeployApplicationRequest(unittest.TestCase):
    """ServingDeployApplicationRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ServingDeployApplicationRequest:
        """Test ServingDeployApplicationRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ServingDeployApplicationRequest`
        """
        model = ServingDeployApplicationRequest()
        if include_optional:
            return ServingDeployApplicationRequest(
                namespace = '',
                name = '',
                subdomain = '',
                source = cloudera.ai.inference.models.serving/application_source.serving.ApplicationSource(
                    container_source = cloudera.ai.inference.models.serving/application_container_source.serving.ApplicationContainerSource(
                        url = '', 
                        environment_variables = [
                            cloudera.ai.inference.models.serving/environment_variable.serving.EnvironmentVariable(
                                name = '', 
                                value = '', )
                            ], 
                        username = '', 
                        access_token = '', ), 
                    directory_source = cloudera.ai.inference.models.serving/application_directory_source.serving.ApplicationDirectorySource(
                        url = '', 
                        entry_point = '', 
                        runtime_image = '', 
                        credentials = cloudera.ai.inference.models.serving/application_directory_source_credentials.serving.ApplicationDirectorySourceCredentials(
                            github_credentials = cloudera.ai.inference.models.serving/github_source_credentials.serving.GithubSourceCredentials(
                                username = '', 
                                ssh_key = '', 
                                access_token = '', ), 
                            s3_credentials = cloudera.ai.inference.models.serving/s3_source_credentials.serving.S3SourceCredentials(
                                access_key_id = '', 
                                secret_access_key = '', ), ), ), ),
                resources = cloudera.ai.inference.models.serving/resources.serving.Resources(
                    req_cpu = '', 
                    req_memory = '', 
                    num_gpus = '', 
                    gpu_resource_name = '', ),
                autoscaling = cloudera.ai.inference.models.serving/autoscaling.serving.Autoscaling(
                    min_replicas = '', 
                    max_replicas = '', 
                    autoscaling_config = null, ),
                labels = [
                    cloudera.ai.inference.models.serving/label.serving.Label(
                        key = '', 
                        value = '', )
                    ],
                description = '',
                traffic = '',
                instance_type = '',
                is_update = True,
                is_web_app = True
            )
        else:
            return ServingDeployApplicationRequest(
        )
        """

    def testServingDeployApplicationRequest(self):
        """Test ServingDeployApplicationRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Cloudera AI Inference

    CML Serving :: Install and manage CML Serving workloads.

    The version of the OpenAPI document: v1alpha1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from cloudera.ai.inference.api.serving_api import ServingApi


class TestServingApi(unittest.TestCase):
    """ServingApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ServingApi()

    def tearDown(self) -> None:
        pass

    def test_serving_create_cluster_log_archive(self) -> None:
        """Test case for serving_create_cluster_log_archive

        """
        pass

    def test_serving_delete_application(self) -> None:
        """Test case for serving_delete_application

        """
        pass

    def test_serving_delete_cluster_log_archive(self) -> None:
        """Test case for serving_delete_cluster_log_archive

        """
        pass

    def test_serving_delete_endpoint(self) -> None:
        """Test case for serving_delete_endpoint

        """
        pass

    def test_serving_delete_endpoint_rate_limit(self) -> None:
        """Test case for serving_delete_endpoint_rate_limit

        """
        pass

    def test_serving_deploy_application(self) -> None:
        """Test case for serving_deploy_application

        """
        pass

    def test_serving_deploy_endpoint(self) -> None:
        """Test case for serving_deploy_endpoint

        """
        pass

    def test_serving_describe_application(self) -> None:
        """Test case for serving_describe_application

        """
        pass

    def test_serving_describe_endpoint(self) -> None:
        """Test case for serving_describe_endpoint

        """
        pass

    def test_serving_describe_service(self) -> None:
        """Test case for serving_describe_service

        """
        pass

    def test_serving_describe_service_health(self) -> None:
        """Test case for serving_describe_service_health

        """
        pass

    def test_serving_get_allowed_environment_variables(self) -> None:
        """Test case for serving_get_allowed_environment_variables

        """
        pass

    def test_serving_get_allowed_vllm_args(self) -> None:
        """Test case for serving_get_allowed_vllm_args

        """
        pass

    def test_serving_get_api_logs(self) -> None:
        """Test case for serving_get_api_logs

        """
        pass

    def test_serving_get_application_logs(self) -> None:
        """Test case for serving_get_application_logs

        """
        pass

    def test_serving_get_endpoint_events(self) -> None:
        """Test case for serving_get_endpoint_events

        """
        pass

    def test_serving_get_endpoint_logs(self) -> None:
        """Test case for serving_get_endpoint_logs

        """
        pass

    def test_serving_get_endpoint_rate_limit(self) -> None:
        """Test case for serving_get_endpoint_rate_limit

        """
        pass

    def test_serving_get_quota_usage(self) -> None:
        """Test case for serving_get_quota_usage

        """
        pass

    def test_serving_grant_permission(self) -> None:
        """Test case for serving_grant_permission

        """
        pass

    def test_serving_list_applications(self) -> None:
        """Test case for serving_list_applications

        """
        pass

    def test_serving_list_cluster_log_archives(self) -> None:
        """Test case for serving_list_cluster_log_archives

        """
        pass

    def test_serving_list_cluster_resources(self) -> None:
        """Test case for serving_list_cluster_resources

        """
        pass

    def test_serving_list_endpoints(self) -> None:
        """Test case for serving_list_endpoints

        """
        pass

    def test_serving_list_permissions(self) -> None:
        """Test case for serving_list_permissions

        """
        pass

    def test_serving_ping(self) -> None:
        """Test case for serving_ping

        """
        pass

    def test_serving_revoke_permission(self) -> None:
        """Test case for serving_revoke_permission

        """
        pass

    def test_serving_set_endpoint_rate_limit(self) -> None:
        """Test case for serving_set_endpoint_rate_limit

        """
        pass

    def test_serving_start_endpoint(self) -> None:
        """Test case for serving_start_endpoint

        """
        pass

    def test_serving_stop_endpoint(self) -> None:
        """Test case for serving_stop_endpoint

        """
        pass

    def test_serving_toggle_features(self) -> None:
        """Test case for serving_toggle_features

        """
        pass

    def test_serving_update_endpoint(self) -> None:
        """Test case for serving_update_endpoint

        """
        pass

    def test_serving_update_inference_logging_config(self) -> None:
        """Test case for serving_update_inference_logging_config

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Cloudera AI Inference

    CML Serving :: Install and manage CML Serving workloads.

    The version of the OpenAPI document: v1alpha1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from cloudera.ai.inference.models.serving_aws_credentials import ServingAWSCredentials
from cloudera.ai.inference.models.serving_gcp_credentials import ServingGCPCredentials
from typing import Optional, Set
from typing_extensions import Self

class ServingThirdPartySource(BaseModel):
    """
    Source for third-party LLM API endpoints (e.g., OpenAI, Azure OpenAI, AWS Bedrock, Gemini)
    """ # noqa: E501
    url: Optional[StrictStr] = Field(default=None, description="Target base URL of the external LLM API (e.g., \"https://api.openai.com\")")
    model: Optional[StrictStr] = Field(default=None, description="Model identifier (e.g., \"gpt-4o-mini\" for OpenAI, deployment name for Azure)")
    provider_type: Optional[StrictStr] = Field(default=None, description="Provider type determines schema translation, auth mechanism, and token counting")
    api_key: Optional[StrictStr] = Field(default=None, description="API key for OpenAI, Azure OpenAI")
    aws_credentials: Optional[ServingAWSCredentials] = Field(default=None, description="AWS credentials for Bedrock")
    gcp_credentials: Optional[ServingGCPCredentials] = Field(default=None, description="GCP credentials for Gemini (Vertex AI)")
    api_version: Optional[StrictStr] = Field(default=None, description="API version (required for Azure OpenAI, e.g., \"2024-10-21\")")
    path_prefix: Optional[StrictStr] = Field(default=None, description="Optional path prefix for the provider API (e.g., \"/v1beta/openai\" for Gemini)")
    __properties: ClassVar[List[str]] = ["url", "model", "provider_type", "api_key", "aws_credentials", "gcp_credentials", "api_version", "path_prefix"]

    @field_validator('provider_type')
    def provider_type_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['THIRD_PARTY_PROVIDER_UNSPECIFIED', 'OPENAI', 'AZURE_OPENAI', 'AWS_BEDROCK', 'GEMINI']):
            raise ValueError("must be one of enum values ('THIRD_PARTY_PROVIDER_UNSPECIFIED', 'OPENAI', 'AZURE_OPENAI', 'AWS_BEDROCK', 'GEMINI')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ServingThirdPartySource from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of aws_credentials
        if self.aws_credentials:
            _dict['aws_credentials'] = self.aws_credentials.to_dict()
        # override the default output from pydantic by calling `to_dict()` of gcp_credentials
        if self.gcp_credentials:
            _dict['gcp_credentials'] = self.gcp_credentials.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ServingThirdPartySource from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "url": obj.get("url"),
            "model": obj.get("model"),
            "provider_type": obj.get("provider_type"),
            "api_key": obj.get("api_key"),
            "aws_credentials": ServingAWSCredentials.from_dict(obj["aws_credentials"]) if obj.get("aws_credentials") is not None else None,
            "gcp_credentials": ServingGCPCredentials.from_dict(obj["gcp_credentials"]) if obj.get("gcp_credentials") is not None else None,
            "api_version": obj.get("api_version"),
            "path_prefix": obj.get("path_prefix")
        })
        return _obj





# coding: utf-8

"""
    Cloudera AI Inference

    CML Serving :: Install and manage CML Serving workloads.

    The version of the OpenAPI document: v1alpha1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from cloudera.ai.inference.models.serving_inference_logging_config import ServingInferenceLoggingConfig

class TestServingInferenceLoggingConfig(unittest.TestCase):
    """ServingInferenceLoggingConfig unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ServingInferenceLoggingConfig:
        """Test ServingInferenceLoggingConfig
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ServingInferenceLoggingConfig`
        """
        model = ServingInferenceLoggingConfig()
        if include_optional:
            return ServingInferenceLoggingConfig(
                enabled = True,
                explainer_s3_config = cloudera.ai.inference.models.serving/s3_inference_logging_config.serving.S3InferenceLoggingConfig(
                    bucket_url = '', 
                    access_key_id = '', 
                    secret_access_key = '', 
                    region = '', ),
                explainer_abs_config = cloudera.ai.inference.models.serving/abs_inference_logging_config.serving.ABSInferenceLoggingConfig(
                    bucket_url = '', 
                    client_id = '', 
                    client_secret = '', 
                    tenant_id = '', 
                    subscription_id = '', 
                    access_token = '', 
                    access_token_expiration_seconds = 56, 
                    service_url = '', ),
                explainer_gcs_config = cloudera.ai.inference.models.serving/gcs_inference_logging_config.serving.GCSInferenceLoggingConfig(
                    bucket_url = '', 
                    key_file = '', ),
                explainer_datalake_config = cloudera.ai.inference.models.serving/data_lake_logging_config.serving.DataLakeLoggingConfig(
                    datalake_crn = '', 
                    path = '', 
                    resolved_storage_url = '', ),
                predictor_s3_config = cloudera.ai.inference.models.serving/s3_inference_logging_config.serving.S3InferenceLoggingConfig(
                    bucket_url = '', 
                    access_key_id = '', 
                    secret_access_key = '', 
                    region = '', ),
                predictor_abs_config = cloudera.ai.inference.models.serving/abs_inference_logging_config.serving.ABSInferenceLoggingConfig(
                    bucket_url = '', 
                    client_id = '', 
                    client_secret = '', 
                    tenant_id = '', 
                    subscription_id = '', 
                    access_token = '', 
                    access_token_expiration_seconds = 56, 
                    service_url = '', ),
                predictor_gcs_config = cloudera.ai.inference.models.serving/gcs_inference_logging_config.serving.GCSInferenceLoggingConfig(
                    bucket_url = '', 
                    key_file = '', ),
                predictor_datalake_config = cloudera.ai.inference.models.serving/data_lake_logging_config.serving.DataLakeLoggingConfig(
                    datalake_crn = '', 
                    path = '', 
                    resolved_storage_url = '', ),
                transformer_s3_config = cloudera.ai.inference.models.serving/s3_inference_logging_config.serving.S3InferenceLoggingConfig(
                    bucket_url = '', 
                    access_key_id = '', 
                    secret_access_key = '', 
                    region = '', ),
                transformer_abs_config = cloudera.ai.inference.models.serving/abs_inference_logging_config.serving.ABSInferenceLoggingConfig(
                    bucket_url = '', 
                    client_id = '', 
                    client_secret = '', 
                    tenant_id = '', 
                    subscription_id = '', 
                    access_token = '', 
                    access_token_expiration_seconds = 56, 
                    service_url = '', ),
                transformer_gcs_config = cloudera.ai.inference.models.serving/gcs_inference_logging_config.serving.GCSInferenceLoggingConfig(
                    bucket_url = '', 
                    key_file = '', ),
                transformer_datalake_config = cloudera.ai.inference.models.serving/data_lake_logging_config.serving.DataLakeLoggingConfig(
                    datalake_crn = '', 
                    path = '', 
                    resolved_storage_url = '', ),
                format = 'LOGGING_FORMAT_UNKNOWN',
                batch_size = 56,
                rollover_frequency = 'ROLLOVER_FREQUENCY_UNKNOWN'
            )
        else:
            return ServingInferenceLoggingConfig(
        )
        """

    def testServingInferenceLoggingConfig(self):
        """Test ServingInferenceLoggingConfig"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Cloudera AI Inference

    CML Serving :: Install and manage CML Serving workloads.

    The version of the OpenAPI document: v1alpha1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictBool, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing import Optional, Set
from typing_extensions import Self

class ServingVLLMEngineArgs(BaseModel):
    """
    Arguments passed to the vllm engine for transformer models.
    """ # noqa: E501
    dtype: Optional[StrictStr] = None
    enable_prefix_caching: Optional[StrictBool] = None
    gpu_memory_utilization: Optional[Union[StrictFloat, StrictInt]] = None
    load_format: Optional[StrictStr] = None
    max_model_length: Optional[StrictInt] = None
    max_num_batched_tokens: Optional[StrictInt] = None
    max_num_seqs: Optional[StrictInt] = None
    quantization: Optional[StrictStr] = None
    enforce_eager: Optional[StrictBool] = None
    trust_remote_code: Optional[StrictBool] = None
    kv_cache_dtype: Optional[StrictStr] = None
    block_size: Optional[StrictInt] = None
    cpu_offload_gb: Optional[StrictInt] = None
    __properties: ClassVar[List[str]] = ["dtype", "enable_prefix_caching", "gpu_memory_utilization", "load_format", "max_model_length", "max_num_batched_tokens", "max_num_seqs", "quantization", "enforce_eager", "trust_remote_code", "kv_cache_dtype", "block_size", "cpu_offload_gb"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ServingVLLMEngineArgs from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ServingVLLMEngineArgs from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "dtype": obj.get("dtype"),
            "enable_prefix_caching": obj.get("enable_prefix_caching"),
            "gpu_memory_utilization": obj.get("gpu_memory_utilization"),
            "load_format": obj.get("load_format"),
            "max_model_length": obj.get("max_model_length"),
            "max_num_batched_tokens": obj.get("max_num_batched_tokens"),
            "max_num_seqs": obj.get("max_num_seqs"),
            "quantization": obj.get("quantization"),
            "enforce_eager": obj.get("enforce_eager"),
            "trust_remote_code": obj.get("trust_remote_code"),
            "kv_cache_dtype": obj.get("kv_cache_dtype"),
            "block_size": obj.get("block_size"),
            "cpu_offload_gb": obj.get("cpu_offload_gb")
        })
        return _obj





# coding: utf-8

"""
    Cloudera AI Inference

    CML Serving :: Install and manage CML Serving workloads.

    The version of the OpenAPI document: v1alpha1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field
from typing import Any, ClassVar, Dict, List, Optional
from cloudera.ai.inference.models.serving_service_status import ServingServiceStatus
from typing import Optional, Set
from typing_extensions import Self

class ServingDescribeServiceHealthResponse(BaseModel):
    """
    ServingDescribeServiceHealthResponse
    """ # noqa: E501
    cml_serving_api: Optional[ServingServiceStatus] = Field(default=None, alias="cmlServingApi")
    kubernetes: Optional[ServingServiceStatus] = None
    knative: Optional[ServingServiceStatus] = None
    kserve: Optional[ServingServiceStatus] = None
    istio: Optional[ServingServiceStatus] = None
    cml_registry: Optional[ServingServiceStatus] = Field(default=None, alias="cmlRegistry")
    cml_client: Optional[ServingServiceStatus] = Field(default=None, alias="cmlClient")
    archiver_client: Optional[ServingServiceStatus] = Field(default=None, alias="archiverClient")
    usage_reporter_client: Optional[ServingServiceStatus] = Field(default=None, alias="usageReporterClient")
    authorizer_client: Optional[ServingServiceStatus] = Field(default=None, alias="authorizerClient")
    __properties: ClassVar[List[str]] = ["cmlServingApi", "kubernetes", "knative", "kserve", "istio", "cmlRegistry", "cmlClient", "archiverClient", "usageReporterClient", "authorizerClient"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ServingDescribeServiceHealthResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of cml_serving_api
        if self.cml_serving_api:
            _dict['cmlServingApi'] = self.cml_serving_api.to_dict()
        # override the default output from pydantic by calling `to_dict()` of kubernetes
        if self.kubernetes:
            _dict['kubernetes'] = self.kubernetes.to_dict()
        # override the default output from pydantic by calling `to_dict()` of knative
        if self.knative:
            _dict['knative'] = self.knative.to_dict()
        # override the default output from pydantic by calling `to_dict()` of kserve
        if self.kserve:
            _dict['kserve'] = self.kserve.to_dict()
        # override the default output from pydantic by calling `to_dict()` of istio
        if self.istio:
            _dict['istio'] = self.istio.to_dict()
        # override the default output from pydantic by calling `to_dict()` of cml_registry
        if self.cml_registry:
            _dict['cmlRegistry'] = self.cml_registry.to_dict()
        # override the default output from pydantic by calling `to_dict()` of cml_client
        if self.cml_client:
            _dict['cmlClient'] = self.cml_client.to_dict()
        # override the default output from pydantic by calling `to_dict()` of archiver_client
        if self.archiver_client:
            _dict['archiverClient'] = self.archiver_client.to_dict()
        # override the default output from pydantic by calling `to_dict()` of usage_reporter_client
        if self.usage_reporter_client:
            _dict['usageReporterClient'] = self.usage_reporter_client.to_dict()
        # override the default output from pydantic by calling `to_dict()` of authorizer_client
        if self.authorizer_client:
            _dict['authorizerClient'] = self.authorizer_client.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ServingDescribeServiceHealthResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "cmlServingApi": ServingServiceStatus.from_dict(obj["cmlServingApi"]) if obj.get("cmlServingApi") is not None else None,
            "kubernetes": ServingServiceStatus.from_dict(obj["kubernetes"]) if obj.get("kubernetes") is not None else None,
            "knative": ServingServiceStatus.from_dict(obj["knative"]) if obj.get("knative") is not None else None,
            "kserve": ServingServiceStatus.from_dict(obj["kserve"]) if obj.get("kserve") is not None else None,
            "istio": ServingServiceStatus.from_dict(obj["istio"]) if obj.get("istio") is not None else None,
            "cmlRegistry": ServingServiceStatus.from_dict(obj["cmlRegistry"]) if obj.get("cmlRegistry") is not None else None,
            "cmlClient": ServingServiceStatus.from_dict(obj["cmlClient"]) if obj.get("cmlClient") is not None else None,
            "archiverClient": ServingServiceStatus.from_dict(obj["archiverClient"]) if obj.get("archiverClient") is not None else None,
            "usageReporterClient": ServingServiceStatus.from_dict(obj["usageReporterClient"]) if obj.get("usageReporterClient") is not None else None,
            "authorizerClient": ServingServiceStatus.from_dict(obj["authorizerClient"]) if obj.get("authorizerClient") is not None else None
        })
        return _obj





# coding: utf-8

# flake8: noqa

"""
    Cloudera AI Inference

    CML Serving :: Install and manage CML Serving workloads.

    The version of the OpenAPI document: v1alpha1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "0.0.1+devel"

# Define package exports
__all__ = [
    "ServingApi",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "ArchiverClusterLogArchiveMetadata",
    "ArchiverCreateClusterLogArchiveRequest",
    "ArchiverCreateClusterLogArchiveResponse",
    "ArchiverDeleteClusterLogArchiveRequest",
    "ArchiverDeleteClusterLogArchiveResponse",
    "ArchiverListClusterLogArchivesRequest",
    "ArchiverListClusterLogArchivesResponse",
    "AuthorizerGrantPermissionRequest",
    "AuthorizerListPermissionsRequest",
    "AuthorizerListPermissionsResponse",
    "AuthorizerPermission",
    "AuthorizerPermissions",
    "AuthorizerResource",
    "AuthorizerRevokePermissionRequest",
    "AuthorizerSubject",
    "GoogleProtobufAny",
    "GoogleRpcStatus",
    "ServingABSInferenceLoggingConfig",
    "ServingAWSCredentials",
    "ServingApplicationContainerSource",
    "ServingApplicationDescriptor",
    "ServingApplicationDirectorySource",
    "ServingApplicationDirectorySourceCredentials",
    "ServingApplicationRevision",
    "ServingApplicationSource",
    "ServingAutoscaling",
    "ServingAutoscalingConfig",
    "ServingCondition",
    "ServingDataLakeLoggingConfig",
    "ServingDeleteApplicationRequest",
    "ServingDeleteEndpointRateLimitRequest",
    "ServingDeleteEndpointRequest",
    "ServingDeployApplicationRequest",
    "ServingDeployEndpointRequest",
    "ServingDeployEndpointResponse",
    "ServingDescribeApplicationRequest",
    "ServingDescribeApplicationResponse",
    "ServingDescribeEndpointRequest",
    "ServingDescribeEndpointResponse",
    "ServingDescribeServiceHealthResponse",
    "ServingDescribeServiceResponse",
    "ServingEmbedConfig",
    "ServingEndpointDescriptor",
    "ServingEndpointEventDetails",
    "ServingEnvironmentVariable",
    "ServingFeaturesStatus",
    "ServingGCPCredentials",
    "ServingGCSInferenceLoggingConfig",
    "ServingGetAPILogsRequest",
    "ServingGetAPILogsResponse",
    "ServingGetAllowedEnvironmentVariablesRequest",
    "ServingGetAllowedEnvironmentVariablesResponse",
    "ServingGetAllowedVLLMArgsResponse",
    "ServingGetApplicationLogsRequest",
    "ServingGetApplicationLogsResponse",
    "ServingGetEndpointEventRequest",
    "ServingGetEndpointEventResponse",
    "ServingGetEndpointLogsRequest",
    "ServingGetEndpointLogsResponse",
    "ServingGetEndpointRateLimitRequest",
    "ServingGetEndpointRateLimitResponse",
    "ServingGetQuotaUsageRequest",
    "ServingGetQuotaUsageResponse",
    "ServingGithubSourceCredentials",
    "ServingInferenceLoggingConfig",
    "ServingInstanceDetails",
    "ServingLabel",
    "ServingListApplicationsRequest",
    "ServingListApplicationsResponse",
    "ServingListClusterResourcesRequest",
    "ServingListClusterResourcesResponse",
    "ServingListEndpointsRequest",
    "ServingListEndpointsResponse",
    "ServingModelRevision",
    "ServingModelSource",
    "ServingModelStatus",
    "ServingOptimizationProfile",
    "ServingPodLogDetails",
    "ServingQuotaUsage",
    "ServingRankConfig",
    "ServingRateLimit",
    "ServingRateLimitConfig",
    "ServingRegistrySource",
    "ServingRelevantRevisionsMeta",
    "ServingRequestRateLimit",
    "ServingRequestResourceInfo",
    "ServingResources",
    "ServingRevisionMeta",
    "ServingRuntimeInfo",
    "ServingS3InferenceLoggingConfig",
    "ServingS3SourceCredentials",
    "ServingServiceStatus",
    "ServingSetEndpointRateLimitRequest",
    "ServingStartEndpointRequest",
    "ServingStopEndpointRequest",
    "ServingTextGenerationConfig",
    "ServingThirdPartySource",
    "ServingToggleFeaturesRequest",
    "ServingTokenBudget",
    "ServingTraffic",
    "ServingUpdateEndpointRequest",
    "ServingUpdateEndpointResponse",
    "ServingUpdateInferenceLoggingConfigRequest",
    "ServingVLLMEngineArgs",
]

# import apis into sdk package
from cloudera.ai.inference.api.serving_api import ServingApi as ServingApi

# import ApiClient
from cloudera.ai.inference.api_response import ApiResponse as ApiResponse
from cloudera.ai.inference.api_client import ApiClient as ApiClient
from cloudera.ai.inference.configuration import Configuration as Configuration
from cloudera.ai.inference.exceptions import OpenApiException as OpenApiException
from cloudera.ai.inference.exceptions import ApiTypeError as ApiTypeError
from cloudera.ai.inference.exceptions import ApiValueError as ApiValueError
from cloudera.ai.inference.exceptions import ApiKeyError as ApiKeyError
from cloudera.ai.inference.exceptions import ApiAttributeError as ApiAttributeError
from cloudera.ai.inference.exceptions import ApiException as ApiException

# import models into sdk package
from cloudera.ai.inference.models.archiver_cluster_log_archive_metadata import ArchiverClusterLogArchiveMetadata as ArchiverClusterLogArchiveMetadata
from cloudera.ai.inference.models.archiver_create_cluster_log_archive_request import ArchiverCreateClusterLogArchiveRequest as ArchiverCreateClusterLogArchiveRequest
from cloudera.ai.inference.models.archiver_create_cluster_log_archive_response import ArchiverCreateClusterLogArchiveResponse as ArchiverCreateClusterLogArchiveResponse
from cloudera.ai.inference.models.archiver_delete_cluster_log_archive_request import ArchiverDeleteClusterLogArchiveRequest as ArchiverDeleteClusterLogArchiveRequest
from cloudera.ai.inference.models.archiver_delete_cluster_log_archive_response import ArchiverDeleteClusterLogArchiveResponse as ArchiverDeleteClusterLogArchiveResponse
from cloudera.ai.inference.models.archiver_list_cluster_log_archives_request import ArchiverListClusterLogArchivesRequest as ArchiverListClusterLogArchivesRequest
from cloudera.ai.inference.models.archiver_list_cluster_log_archives_response import ArchiverListClusterLogArchivesResponse as ArchiverListClusterLogArchivesResponse
from cloudera.ai.inference.models.authorizer_grant_permission_request import AuthorizerGrantPermissionRequest as AuthorizerGrantPermissionRequest
from cloudera.ai.inference.models.authorizer_list_permissions_request import AuthorizerListPermissionsRequest as AuthorizerListPermissionsRequest
from cloudera.ai.inference.models.authorizer_list_permissions_response import AuthorizerListPermissionsResponse as AuthorizerListPermissionsResponse
from cloudera.ai.inference.models.authorizer_permission import AuthorizerPermission as AuthorizerPermission
from cloudera.ai.inference.models.authorizer_permissions import AuthorizerPermissions as AuthorizerPermissions
from cloudera.ai.inference.models.authorizer_resource import AuthorizerResource as AuthorizerResource
from cloudera.ai.inference.models.authorizer_revoke_permission_request import AuthorizerRevokePermissionRequest as AuthorizerRevokePermissionRequest
from cloudera.ai.inference.models.authorizer_subject import AuthorizerSubject as AuthorizerSubject
from cloudera.ai.inference.models.google_protobuf_any import GoogleProtobufAny as GoogleProtobufAny
from cloudera.ai.inference.models.google_rpc_status import GoogleRpcStatus as GoogleRpcStatus
from cloudera.ai.inference.models.serving_abs_inference_logging_config import ServingABSInferenceLoggingConfig as ServingABSInferenceLoggingConfig
from cloudera.ai.inference.models.serving_aws_credentials import ServingAWSCredentials as ServingAWSCredentials
from cloudera.ai.inference.models.serving_application_container_source import ServingApplicationContainerSource as ServingApplicationContainerSource
from cloudera.ai.inference.models.serving_application_descriptor import ServingApplicationDescriptor as ServingApplicationDescriptor
from cloudera.ai.inference.models.serving_application_directory_source import ServingApplicationDirectorySource as ServingApplicationDirectorySource
from cloudera.ai.inference.models.serving_application_directory_source_credentials import ServingApplicationDirectorySourceCredentials as ServingApplicationDirectorySourceCredentials
from cloudera.ai.inference.models.serving_application_revision import ServingApplicationRevision as ServingApplicationRevision
from cloudera.ai.inference.models.serving_application_source import ServingApplicationSource as ServingApplicationSource
from cloudera.ai.inference.models.serving_autoscaling import ServingAutoscaling as ServingAutoscaling
from cloudera.ai.inference.models.serving_autoscaling_config import ServingAutoscalingConfig as ServingAutoscalingConfig
from cloudera.ai.inference.models.serving_condition import ServingCondition as ServingCondition
from cloudera.ai.inference.models.serving_data_lake_logging_config import ServingDataLakeLoggingConfig as ServingDataLakeLoggingConfig
from cloudera.ai.inference.models.serving_delete_application_request import ServingDeleteApplicationRequest as ServingDeleteApplicationRequest
from cloudera.ai.inference.models.serving_delete_endpoint_rate_limit_request import ServingDeleteEndpointRateLimitRequest as ServingDeleteEndpointRateLimitRequest
from cloudera.ai.inference.models.serving_delete_endpoint_request import ServingDeleteEndpointRequest as ServingDeleteEndpointRequest
from cloudera.ai.inference.models.serving_deploy_application_request import ServingDeployApplicationRequest as ServingDeployApplicationRequest
from cloudera.ai.inference.models.serving_deploy_endpoint_request import ServingDeployEndpointRequest as ServingDeployEndpointRequest
from cloudera.ai.inference.models.serving_deploy_endpoint_response import ServingDeployEndpointResponse as ServingDeployEndpointResponse
from cloudera.ai.inference.models.serving_describe_application_request import ServingDescribeApplicationRequest as ServingDescribeApplicationRequest
from cloudera.ai.inference.models.serving_describe_application_response import ServingDescribeApplicationResponse as ServingDescribeApplicationResponse
from cloudera.ai.inference.models.serving_describe_endpoint_request import ServingDescribeEndpointRequest as ServingDescribeEndpointRequest
from cloudera.ai.inference.models.serving_describe_endpoint_response import ServingDescribeEndpointResponse as ServingDescribeEndpointResponse
from cloudera.ai.inference.models.serving_describe_service_health_response import ServingDescribeServiceHealthResponse as ServingDescribeServiceHealthResponse
from cloudera.ai.inference.models.serving_describe_service_response import ServingDescribeServiceResponse as ServingDescribeServiceResponse
from cloudera.ai.inference.models.serving_embed_config import ServingEmbedConfig as ServingEmbedConfig
from cloudera.ai.inference.models.serving_endpoint_descriptor import ServingEndpointDescriptor as ServingEndpointDescriptor
from cloudera.ai.inference.models.serving_endpoint_event_details import ServingEndpointEventDetails as ServingEndpointEventDetails
from cloudera.ai.inference.models.serving_environment_variable import ServingEnvironmentVariable as ServingEnvironmentVariable
from cloudera.ai.inference.models.serving_features_status import ServingFeaturesStatus as ServingFeaturesStatus
from cloudera.ai.inference.models.serving_gcp_credentials import ServingGCPCredentials as ServingGCPCredentials
from cloudera.ai.inference.models.serving_gcs_inference_logging_config import ServingGCSInferenceLoggingConfig as ServingGCSInferenceLoggingConfig
from cloudera.ai.inference.models.serving_get_api_logs_request import ServingGetAPILogsRequest as ServingGetAPILogsRequest
from cloudera.ai.inference.models.serving_get_api_logs_response import ServingGetAPILogsResponse as ServingGetAPILogsResponse
from cloudera.ai.inference.models.serving_get_allowed_environment_variables_request import ServingGetAllowedEnvironmentVariablesRequest as ServingGetAllowedEnvironmentVariablesRequest
from cloudera.ai.inference.models.serving_get_allowed_environment_variables_response import ServingGetAllowedEnvironmentVariablesResponse as ServingGetAllowedEnvironmentVariablesResponse
from cloudera.ai.inference.models.serving_get_allowed_vllm_args_response import ServingGetAllowedVLLMArgsResponse as ServingGetAllowedVLLMArgsResponse
from cloudera.ai.inference.models.serving_get_application_logs_request import ServingGetApplicationLogsRequest as ServingGetApplicationLogsRequest
from cloudera.ai.inference.models.serving_get_application_logs_response import ServingGetApplicationLogsResponse as ServingGetApplicationLogsResponse
from cloudera.ai.inference.models.serving_get_endpoint_event_request import ServingGetEndpointEventRequest as ServingGetEndpointEventRequest
from cloudera.ai.inference.models.serving_get_endpoint_event_response import ServingGetEndpointEventResponse as ServingGetEndpointEventResponse
from cloudera.ai.inference.models.serving_get_endpoint_logs_request import ServingGetEndpointLogsRequest as ServingGetEndpointLogsRequest
from cloudera.ai.inference.models.serving_get_endpoint_logs_response import ServingGetEndpointLogsResponse as ServingGetEndpointLogsResponse
from cloudera.ai.inference.models.serving_get_endpoint_rate_limit_request import ServingGetEndpointRateLimitRequest as ServingGetEndpointRateLimitRequest
from cloudera.ai.inference.models.serving_get_endpoint_rate_limit_response import ServingGetEndpointRateLimitResponse as ServingGetEndpointRateLimitResponse
from cloudera.ai.inference.models.serving_get_quota_usage_request import ServingGetQuotaUsageRequest as ServingGetQuotaUsageRequest
from cloudera.ai.inference.models.serving_get_quota_usage_response import ServingGetQuotaUsageResponse as ServingGetQuotaUsageResponse
from cloudera.ai.inference.models.serving_github_source_credentials import ServingGithubSourceCredentials as ServingGithubSourceCredentials
from cloudera.ai.inference.models.serving_inference_logging_config import ServingInferenceLoggingConfig as ServingInferenceLoggingConfig
from cloudera.ai.inference.models.serving_instance_details import ServingInstanceDetails as ServingInstanceDetails
from cloudera.ai.inference.models.serving_label import ServingLabel as ServingLabel
from cloudera.ai.inference.models.serving_list_applications_request import ServingListApplicationsRequest as ServingListApplicationsRequest
from cloudera.ai.inference.models.serving_list_applications_response import ServingListApplicationsResponse as ServingListApplicationsResponse
from cloudera.ai.inference.models.serving_list_cluster_resources_request import ServingListClusterResourcesRequest as ServingListClusterResourcesRequest
from cloudera.ai.inference.models.serving_list_cluster_resources_response import ServingListClusterResourcesResponse as ServingListClusterResourcesResponse
from cloudera.ai.inference.models.serving_list_endpoints_request import ServingListEndpointsRequest as ServingListEndpointsRequest
from cloudera.ai.inference.models.serving_list_endpoints_response import ServingListEndpointsResponse as ServingListEndpointsResponse
from cloudera.ai.inference.models.serving_model_revision import ServingModelRevision as ServingModelRevision
from cloudera.ai.inference.models.serving_model_source import ServingModelSource as ServingModelSource
from cloudera.ai.inference.models.serving_model_status import ServingModelStatus as ServingModelStatus
from cloudera.ai.inference.models.serving_optimization_profile import ServingOptimizationProfile as ServingOptimizationProfile
from cloudera.ai.inference.models.serving_pod_log_details import ServingPodLogDetails as ServingPodLogDetails
from cloudera.ai.inference.models.serving_quota_usage import ServingQuotaUsage as ServingQuotaUsage
from cloudera.ai.inference.models.serving_rank_config import ServingRankConfig as ServingRankConfig
from cloudera.ai.inference.models.serving_rate_limit import ServingRateLimit as ServingRateLimit
from cloudera.ai.inference.models.serving_rate_limit_config import ServingRateLimitConfig as ServingRateLimitConfig
from cloudera.ai.inference.models.serving_registry_source import ServingRegistrySource as ServingRegistrySource
from cloudera.ai.inference.models.serving_relevant_revisions_meta import ServingRelevantRevisionsMeta as ServingRelevantRevisionsMeta
from cloudera.ai.inference.models.serving_request_rate_limit import ServingRequestRateLimit as ServingRequestRateLimit
from cloudera.ai.inference.models.serving_request_resource_info import ServingRequestResourceInfo as ServingRequestResourceInfo
from cloudera.ai.inference.models.serving_resources import ServingResources as ServingResources
from cloudera.ai.inference.models.serving_revision_meta import ServingRevisionMeta as ServingRevisionMeta
from cloudera.ai.inference.models.serving_runtime_info import ServingRuntimeInfo as ServingRuntimeInfo
from cloudera.ai.inference.models.serving_s3_inference_logging_config import ServingS3InferenceLoggingConfig as ServingS3InferenceLoggingConfig
from cloudera.ai.inference.models.serving_s3_source_credentials import ServingS3SourceCredentials as ServingS3SourceCredentials
from cloudera.ai.inference.models.serving_service_status import ServingServiceStatus as ServingServiceStatus
from cloudera.ai.inference.models.serving_set_endpoint_rate_limit_request import ServingSetEndpointRateLimitRequest as ServingSetEndpointRateLimitRequest
from cloudera.ai.inference.models.serving_start_endpoint_request import ServingStartEndpointRequest as ServingStartEndpointRequest
from cloudera.ai.inference.models.serving_stop_endpoint_request import ServingStopEndpointRequest as ServingStopEndpointRequest
from cloudera.ai.inference.models.serving_text_generation_config import ServingTextGenerationConfig as ServingTextGenerationConfig
from cloudera.ai.inference.models.serving_third_party_source import ServingThirdPartySource as ServingThirdPartySource
from cloudera.ai.inference.models.serving_toggle_features_request import ServingToggleFeaturesRequest as ServingToggleFeaturesRequest
from cloudera.ai.inference.models.serving_token_budget import ServingTokenBudget as ServingTokenBudget
from cloudera.ai.inference.models.serving_traffic import ServingTraffic as ServingTraffic
from cloudera.ai.inference.models.serving_update_endpoint_request import ServingUpdateEndpointRequest as ServingUpdateEndpointRequest
from cloudera.ai.inference.models.serving_update_endpoint_response import ServingUpdateEndpointResponse as ServingUpdateEndpointResponse
from cloudera.ai.inference.models.serving_update_inference_logging_config_request import ServingUpdateInferenceLoggingConfigRequest as ServingUpdateInferenceLoggingConfigRequest
from cloudera.ai.inference.models.serving_vllm_engine_args import ServingVLLMEngineArgs as ServingVLLMEngineArgs


from cloudera.ai.inference._client import create_client



# coding: utf-8

"""
    Cloudera AI Inference

    CML Serving :: Install and manage CML Serving workloads.

    The version of the OpenAPI document: v1alpha1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from cloudera.ai.inference.models.serving_endpoint_event_details import ServingEndpointEventDetails

class TestServingEndpointEventDetails(unittest.TestCase):
    """ServingEndpointEventDetails unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ServingEndpointEventDetails:
        """Test ServingEndpointEventDetails
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ServingEndpointEventDetails`
        """
        model = ServingEndpointEventDetails()
        if include_optional:
            return ServingEndpointEventDetails(
                event_type = '',
                reason = '',
                event_trigger = '',
                message = '',
                last_seen = '',
                count = 56
            )
        else:
            return ServingEndpointEventDetails(
        )
        """

    def testServingEndpointEventDetails(self):
        """Test ServingEndpointEventDetails"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Cloudera AI Inference

    CML Serving :: Install and manage CML Serving workloads.

    The version of the OpenAPI document: v1alpha1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from cloudera.ai.inference.models.serving_features_status import ServingFeaturesStatus
from cloudera.ai.inference.models.serving_inference_logging_config import ServingInferenceLoggingConfig
from cloudera.ai.inference.models.serving_runtime_info import ServingRuntimeInfo
from typing import Optional, Set
from typing_extensions import Self

class ServingDescribeServiceResponse(BaseModel):
    """
    ServingDescribeServiceResponse
    """ # noqa: E501
    crn: Optional[StrictStr] = None
    version: Optional[StrictStr] = None
    features: Optional[ServingFeaturesStatus] = None
    api_versions: Optional[List[StrictStr]] = Field(default=None, alias="apiVersions")
    runtimes: Optional[List[ServingRuntimeInfo]] = None
    inference_logging_config: Optional[ServingInferenceLoggingConfig] = Field(default=None, alias="inferenceLoggingConfig")
    __properties: ClassVar[List[str]] = ["crn", "version", "features", "apiVersions", "runtimes", "inferenceLoggingConfig"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ServingDescribeServiceResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of features
        if self.features:
            _dict['features'] = self.features.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in runtimes (list)
        _items = []
        if self.runtimes:
            for _item_runtimes in self.runtimes:
                if _item_runtimes:
                    _items.append(_item_runtimes.to_dict())
            _dict['runtimes'] = _items
        # override the default output from pydantic by calling `to_dict()` of inference_logging_config
        if self.inference_logging_config:
            _dict['inferenceLoggingConfig'] = self.inference_logging_config.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ServingDescribeServiceResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "crn": obj.get("crn"),
            "version": obj.get("version"),
            "features": ServingFeaturesStatus.from_dict(obj["features"]) if obj.get("features") is not None else None,
            "apiVersions": obj.get("apiVersions"),
            "runtimes": [ServingRuntimeInfo.from_dict(_item) for _item in obj["runtimes"]] if obj.get("runtimes") is not None else None,
            "inferenceLoggingConfig": ServingInferenceLoggingConfig.from_dict(obj["inferenceLoggingConfig"]) if obj.get("inferenceLoggingConfig") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Cloudera AI Inference

    CML Serving :: Install and manage CML Serving workloads.

    The version of the OpenAPI document: v1alpha1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from cloudera.ai.inference.models.serving_model_revision import ServingModelRevision

class TestServingModelRevision(unittest.TestCase):
    """ServingModelRevision unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ServingModelRevision:
        """Test ServingModelRevision
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ServingModelRevision`
        """
        model = ServingModelRevision()
        if include_optional:
            return ServingModelRevision(
                source = cloudera.ai.inference.models.serving/model_source.serving.ModelSource(
                    registry_source = cloudera.ai.inference.models.serving/registry_source.serving.RegistrySource(
                        model_id = '', 
                        version = 56, 
                        registry_id = '', ), 
                    third_party_source = cloudera.ai.inference.models.serving/third_party_source.serving.ThirdPartySource(
                        url = '', 
                        model = '', 
                        provider_type = 'THIRD_PARTY_PROVIDER_UNSPECIFIED', 
                        api_key = '', 
                        aws_credentials = null, 
                        gcp_credentials = null, 
                        api_version = '', 
                        path_prefix = '', ), ),
                metadata = cloudera.ai.inference.models.serving/revision_meta.serving.RevisionMeta(
                    name = '', 
                    traffic = 56, 
                    desired_replicas = 56, 
                    actual_replicas = 56, 
                    ready = True, 
                    failed = True, 
                    generation = '', 
                    conditions = [
                        cloudera.ai.inference.models.serving/condition.serving.Condition(
                            type = '', 
                            status = '', 
                            severity = '', 
                            last_transition_time = '', 
                            reason = '', 
                            message = '', )
                        ], 
                    replica_names = [
                        ''
                        ], )
            )
        else:
            return ServingModelRevision(
        )
        """

    def testServingModelRevision(self):
        """Test ServingModelRevision"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Cloudera AI Inference

    CML Serving :: Install and manage CML Serving workloads.

    The version of the OpenAPI document: v1alpha1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from cloudera.ai.inference.models.archiver_list_cluster_log_archives_response import ArchiverListClusterLogArchivesResponse

class TestArchiverListClusterLogArchivesResponse(unittest.TestCase):
    """ArchiverListClusterLogArchivesResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ArchiverListClusterLogArchivesResponse:
        """Test ArchiverListClusterLogArchivesResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ArchiverListClusterLogArchivesResponse`
        """
        model = ArchiverListClusterLogArchivesResponse()
        if include_optional:
            return ArchiverListClusterLogArchivesResponse(
                archives = [
                    cloudera.ai.inference.models.archiver/cluster_log_archive_metadata.archiver.ClusterLogArchiveMetadata(
                        archive_id = '', 
                        request = cloudera.ai.inference.models.archiver/create_cluster_log_archive_request.archiver.CreateClusterLogArchiveRequest(
                            uuid = '', 
                            timespan_minutes = 56, 
                            include_endpoints = True, 
                            redact_sensitive_data = True, 
                            send_to_cloudera = True, 
                            case_number = '', 
                            include_applications = True, ), 
                        requested_time = '', 
                        status = 'QUEUED', 
                        bytes = '', )
                    ]
            )
        else:
            return ArchiverListClusterLogArchivesResponse(
        )
        """

    def testArchiverListClusterLogArchivesResponse(self):
        """Test ArchiverListClusterLogArchivesResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Cloudera AI Inference

    CML Serving :: Install and manage CML Serving workloads.

    The version of the OpenAPI document: v1alpha1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from cloudera.ai.inference.models.serving_application_directory_source_credentials import ServingApplicationDirectorySourceCredentials

class TestServingApplicationDirectorySourceCredentials(unittest.TestCase):
    """ServingApplicationDirectorySourceCredentials unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ServingApplicationDirectorySourceCredentials:
        """Test ServingApplicationDirectorySourceCredentials
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ServingApplicationDirectorySourceCredentials`
        """
        model = ServingApplicationDirectorySourceCredentials()
        if include_optional:
            return ServingApplicationDirectorySourceCredentials(
                github_credentials = cloudera.ai.inference.models.serving/github_source_credentials.serving.GithubSourceCredentials(
                    username = '', 
                    ssh_key = '', 
                    access_token = '', ),
                s3_credentials = cloudera.ai.inference.models.serving/s3_source_credentials.serving.S3SourceCredentials(
                    access_key_id = '', 
                    secret_access_key = '', )
            )
        else:
            return ServingApplicationDirectorySourceCredentials(
        )
        """

    def testServingApplicationDirectorySourceCredentials(self):
        """Test ServingApplicationDirectorySourceCredentials"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Cloudera AI Inference

    CML Serving :: Install and manage CML Serving workloads.

    The version of the OpenAPI document: v1alpha1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class ServingApplicationDescriptor(BaseModel):
    """
    ServingApplicationDescriptor
    """ # noqa: E501
    namespace: Optional[StrictStr] = None
    name: Optional[StrictStr] = None
    url: Optional[StrictStr] = None
    created_by: Optional[StrictStr] = None
    subdomain: Optional[StrictStr] = None
    state: Optional[StrictStr] = None
    created_at: Optional[datetime] = None
    last_updated_at: Optional[datetime] = None
    is_web_app: Optional[StrictBool] = None
    __properties: ClassVar[List[str]] = ["namespace", "name", "url", "created_by", "subdomain", "state", "created_at", "last_updated_at", "is_web_app"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ServingApplicationDescriptor from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ServingApplicationDescriptor from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "namespace": obj.get("namespace"),
            "name": obj.get("name"),
            "url": obj.get("url"),
            "created_by": obj.get("created_by"),
            "subdomain": obj.get("subdomain"),
            "state": obj.get("state"),
            "created_at": obj.get("created_at"),
            "last_updated_at": obj.get("last_updated_at"),
            "is_web_app": obj.get("is_web_app")
        })
        return _obj





# coding: utf-8

# flake8: noqa
"""
    Cloudera AI Inference

    CML Serving :: Install and manage CML Serving workloads.

    The version of the OpenAPI document: v1alpha1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

# import models into model package
from cloudera.ai.inference.models.archiver_cluster_log_archive_metadata import ArchiverClusterLogArchiveMetadata
from cloudera.ai.inference.models.archiver_create_cluster_log_archive_request import ArchiverCreateClusterLogArchiveRequest
from cloudera.ai.inference.models.archiver_create_cluster_log_archive_response import ArchiverCreateClusterLogArchiveResponse
from cloudera.ai.inference.models.archiver_delete_cluster_log_archive_request import ArchiverDeleteClusterLogArchiveRequest
from cloudera.ai.inference.models.archiver_delete_cluster_log_archive_response import ArchiverDeleteClusterLogArchiveResponse
from cloudera.ai.inference.models.archiver_list_cluster_log_archives_request import ArchiverListClusterLogArchivesRequest
from cloudera.ai.inference.models.archiver_list_cluster_log_archives_response import ArchiverListClusterLogArchivesResponse
from cloudera.ai.inference.models.authorizer_grant_permission_request import AuthorizerGrantPermissionRequest
from cloudera.ai.inference.models.authorizer_list_permissions_request import AuthorizerListPermissionsRequest
from cloudera.ai.inference.models.authorizer_list_permissions_response import AuthorizerListPermissionsResponse
from cloudera.ai.inference.models.authorizer_permission import AuthorizerPermission
from cloudera.ai.inference.models.authorizer_permissions import AuthorizerPermissions
from cloudera.ai.inference.models.authorizer_resource import AuthorizerResource
from cloudera.ai.inference.models.authorizer_revoke_permission_request import AuthorizerRevokePermissionRequest
from cloudera.ai.inference.models.authorizer_subject import AuthorizerSubject
from cloudera.ai.inference.models.google_protobuf_any import GoogleProtobufAny
from cloudera.ai.inference.models.google_rpc_status import GoogleRpcStatus
from cloudera.ai.inference.models.serving_abs_inference_logging_config import ServingABSInferenceLoggingConfig
from cloudera.ai.inference.models.serving_aws_credentials import ServingAWSCredentials
from cloudera.ai.inference.models.serving_application_container_source import ServingApplicationContainerSource
from cloudera.ai.inference.models.serving_application_descriptor import ServingApplicationDescriptor
from cloudera.ai.inference.models.serving_application_directory_source import ServingApplicationDirectorySource
from cloudera.ai.inference.models.serving_application_directory_source_credentials import ServingApplicationDirectorySourceCredentials
from cloudera.ai.inference.models.serving_application_revision import ServingApplicationRevision
from cloudera.ai.inference.models.serving_application_source import ServingApplicationSource
from cloudera.ai.inference.models.serving_autoscaling import ServingAutoscaling
from cloudera.ai.inference.models.serving_autoscaling_config import ServingAutoscalingConfig
from cloudera.ai.inference.models.serving_condition import ServingCondition
from cloudera.ai.inference.models.serving_data_lake_logging_config import ServingDataLakeLoggingConfig
from cloudera.ai.inference.models.serving_delete_application_request import ServingDeleteApplicationRequest
from cloudera.ai.inference.models.serving_delete_endpoint_rate_limit_request import ServingDeleteEndpointRateLimitRequest
from cloudera.ai.inference.models.serving_delete_endpoint_request import ServingDeleteEndpointRequest
from cloudera.ai.inference.models.serving_deploy_application_request import ServingDeployApplicationRequest
from cloudera.ai.inference.models.serving_deploy_endpoint_request import ServingDeployEndpointRequest
from cloudera.ai.inference.models.serving_deploy_endpoint_response import ServingDeployEndpointResponse
from cloudera.ai.inference.models.serving_describe_application_request import ServingDescribeApplicationRequest
from cloudera.ai.inference.models.serving_describe_application_response import ServingDescribeApplicationResponse
from cloudera.ai.inference.models.serving_describe_endpoint_request import ServingDescribeEndpointRequest
from cloudera.ai.inference.models.serving_describe_endpoint_response import ServingDescribeEndpointResponse
from cloudera.ai.inference.models.serving_describe_service_health_response import ServingDescribeServiceHealthResponse
from cloudera.ai.inference.models.serving_describe_service_response import ServingDescribeServiceResponse
from cloudera.ai.inference.models.serving_embed_config import ServingEmbedConfig
from cloudera.ai.inference.models.serving_endpoint_descriptor import ServingEndpointDescriptor
from cloudera.ai.inference.models.serving_endpoint_event_details import ServingEndpointEventDetails
from cloudera.ai.inference.models.serving_environment_variable import ServingEnvironmentVariable
from cloudera.ai.inference.models.serving_features_status import ServingFeaturesStatus
from cloudera.ai.inference.models.serving_gcp_credentials import ServingGCPCredentials
from cloudera.ai.inference.models.serving_gcs_inference_logging_config import ServingGCSInferenceLoggingConfig
from cloudera.ai.inference.models.serving_get_api_logs_request import ServingGetAPILogsRequest
from cloudera.ai.inference.models.serving_get_api_logs_response import ServingGetAPILogsResponse
from cloudera.ai.inference.models.serving_get_allowed_environment_variables_request import ServingGetAllowedEnvironmentVariablesRequest
from cloudera.ai.inference.models.serving_get_allowed_environment_variables_response import ServingGetAllowedEnvironmentVariablesResponse
from cloudera.ai.inference.models.serving_get_allowed_vllm_args_response import ServingGetAllowedVLLMArgsResponse
from cloudera.ai.inference.models.serving_get_application_logs_request import ServingGetApplicationLogsRequest
from cloudera.ai.inference.models.serving_get_application_logs_response import ServingGetApplicationLogsResponse
from cloudera.ai.inference.models.serving_get_endpoint_event_request import ServingGetEndpointEventRequest
from cloudera.ai.inference.models.serving_get_endpoint_event_response import ServingGetEndpointEventResponse
from cloudera.ai.inference.models.serving_get_endpoint_logs_request import ServingGetEndpointLogsRequest
from cloudera.ai.inference.models.serving_get_endpoint_logs_response import ServingGetEndpointLogsResponse
from cloudera.ai.inference.models.serving_get_endpoint_rate_limit_request import ServingGetEndpointRateLimitRequest
from cloudera.ai.inference.models.serving_get_endpoint_rate_limit_response import ServingGetEndpointRateLimitResponse
from cloudera.ai.inference.models.serving_get_quota_usage_request import ServingGetQuotaUsageRequest
from cloudera.ai.inference.models.serving_get_quota_usage_response import ServingGetQuotaUsageResponse
from cloudera.ai.inference.models.serving_github_source_credentials import ServingGithubSourceCredentials
from cloudera.ai.inference.models.serving_inference_logging_config import ServingInferenceLoggingConfig
from cloudera.ai.inference.models.serving_instance_details import ServingInstanceDetails
from cloudera.ai.inference.models.serving_label import ServingLabel
from cloudera.ai.inference.models.serving_list_applications_request import ServingListApplicationsRequest
from cloudera.ai.inference.models.serving_list_applications_response import ServingListApplicationsResponse
from cloudera.ai.inference.models.serving_list_cluster_resources_request import ServingListClusterResourcesRequest
from cloudera.ai.inference.models.serving_list_cluster_resources_response import ServingListClusterResourcesResponse
from cloudera.ai.inference.models.serving_list_endpoints_request import ServingListEndpointsRequest
from cloudera.ai.inference.models.serving_list_endpoints_response import ServingListEndpointsResponse
from cloudera.ai.inference.models.serving_model_revision import ServingModelRevision
from cloudera.ai.inference.models.serving_model_source import ServingModelSource
from cloudera.ai.inference.models.serving_model_status import ServingModelStatus
from cloudera.ai.inference.models.serving_optimization_profile import ServingOptimizationProfile
from cloudera.ai.inference.models.serving_pod_log_details import ServingPodLogDetails
from cloudera.ai.inference.models.serving_quota_usage import ServingQuotaUsage
from cloudera.ai.inference.models.serving_rank_config import ServingRankConfig
from cloudera.ai.inference.models.serving_rate_limit import ServingRateLimit
from cloudera.ai.inference.models.serving_rate_limit_config import ServingRateLimitConfig
from cloudera.ai.inference.models.serving_registry_source import ServingRegistrySource
from cloudera.ai.inference.models.serving_relevant_revisions_meta import ServingRelevantRevisionsMeta
from cloudera.ai.inference.models.serving_request_rate_limit import ServingRequestRateLimit
from cloudera.ai.inference.models.serving_request_resource_info import ServingRequestResourceInfo
from cloudera.ai.inference.models.serving_resources import ServingResources
from cloudera.ai.inference.models.serving_revision_meta import ServingRevisionMeta
from cloudera.ai.inference.models.serving_runtime_info import ServingRuntimeInfo
from cloudera.ai.inference.models.serving_s3_inference_logging_config import ServingS3InferenceLoggingConfig
from cloudera.ai.inference.models.serving_s3_source_credentials import ServingS3SourceCredentials
from cloudera.ai.inference.models.serving_service_status import ServingServiceStatus
from cloudera.ai.inference.models.serving_set_endpoint_rate_limit_request import ServingSetEndpointRateLimitRequest
from cloudera.ai.inference.models.serving_start_endpoint_request import ServingStartEndpointRequest
from cloudera.ai.inference.models.serving_stop_endpoint_request import ServingStopEndpointRequest
from cloudera.ai.inference.models.serving_text_generation_config import ServingTextGenerationConfig
from cloudera.ai.inference.models.serving_third_party_source import ServingThirdPartySource
from cloudera.ai.inference.models.serving_toggle_features_request import ServingToggleFeaturesRequest
from cloudera.ai.inference.models.serving_token_budget import ServingTokenBudget
from cloudera.ai.inference.models.serving_traffic import ServingTraffic
from cloudera.ai.inference.models.serving_update_endpoint_request import ServingUpdateEndpointRequest
from cloudera.ai.inference.models.serving_update_endpoint_response import ServingUpdateEndpointResponse
from cloudera.ai.inference.models.serving_update_inference_logging_config_request import ServingUpdateInferenceLoggingConfigRequest
from cloudera.ai.inference.models.serving_vllm_engine_args import ServingVLLMEngineArgs




# coding: utf-8

"""
    Cloudera AI Inference

    CML Serving :: Install and manage CML Serving workloads.

    The version of the OpenAPI document: v1alpha1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from cloudera.ai.inference.models.serving_describe_application_response import ServingDescribeApplicationResponse

class TestServingDescribeApplicationResponse(unittest.TestCase):
    """ServingDescribeApplicationResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ServingDescribeApplicationResponse:
        """Test ServingDescribeApplicationResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ServingDescribeApplicationResponse`
        """
        model = ServingDescribeApplicationResponse()
        if include_optional:
            return ServingDescribeApplicationResponse(
                namespace = '',
                name = '',
                url = '',
                conditions = [
                    cloudera.ai.inference.models.serving/condition.serving.Condition(
                        type = '', 
                        status = '', 
                        severity = '', 
                        last_transition_time = '', 
                        reason = '', 
                        message = '', )
                    ],
                subdomain = '',
                observed_generation = 56,
                created_by = '',
                description = '',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                resources = cloudera.ai.inference.models.serving/resources.serving.Resources(
                    req_cpu = '', 
                    req_memory = '', 
                    num_gpus = '', 
                    gpu_resource_name = '', ),
                revisions = [
                    cloudera.ai.inference.models.serving/application_revision.serving.ApplicationRevision(
                        source = cloudera.ai.inference.models.serving/application_source.serving.ApplicationSource(
                            container_source = cloudera.ai.inference.models.serving/application_container_source.serving.ApplicationContainerSource(
                                url = '', 
                                environment_variables = [
                                    cloudera.ai.inference.models.serving/environment_variable.serving.EnvironmentVariable(
                                        name = '', 
                                        value = '', )
                                    ], 
                                username = '', 
                                access_token = '', ), 
                            directory_source = cloudera.ai.inference.models.serving/application_directory_source.serving.ApplicationDirectorySource(
                                url = '', 
                                entry_point = '', 
                                runtime_image = '', 
                                credentials = cloudera.ai.inference.models.serving/application_directory_source_credentials.serving.ApplicationDirectorySourceCredentials(
                                    github_credentials = cloudera.ai.inference.models.serving/github_source_credentials.serving.GithubSourceCredentials(
                                        username = '', 
                                        ssh_key = '', 
                                        access_token = '', ), 
                                    s3_credentials = cloudera.ai.inference.models.serving/s3_source_credentials.serving.S3SourceCredentials(
                                        access_key_id = '', 
                                        secret_access_key = '', ), ), ), ), 
                        metadata = cloudera.ai.inference.models.serving/revision_meta.serving.RevisionMeta(
                            name = '', 
                            traffic = 56, 
                            desired_replicas = 56, 
                            actual_replicas = 56, 
                            ready = True, 
                            failed = True, 
                            generation = '', 
                            conditions = [
                                cloudera.ai.inference.models.serving/condition.serving.Condition(
                                    type = '', 
                                    status = '', 
                                    severity = '', 
                                    last_transition_time = '', 
                                    reason = '', 
                                    message = '', )
                                ], 
                            replica_names = [
                                ''
                                ], ), )
                    ],
                relevant_revisions = cloudera.ai.inference.models.serving/relevant_revisions_meta.serving.RelevantRevisionsMeta(
                    latest_created_revision = '', 
                    latest_ready_revision = '', 
                    latest_rolledout_revision = '', 
                    previous_rolledout_revision = '', ),
                autoscaling = cloudera.ai.inference.models.serving/autoscaling.serving.Autoscaling(
                    min_replicas = '', 
                    max_replicas = '', 
                    autoscaling_config = null, ),
                state = '',
                last_updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                is_web_app = True,
                source_url = ''
            )
        else:
            return ServingDescribeApplicationResponse(
        )
        """

    def testServingDescribeApplicationResponse(self):
        """Test ServingDescribeApplicationResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Cloudera AI Inference

    CML Serving :: Install and manage CML Serving workloads.

    The version of the OpenAPI document: v1alpha1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class ServingQuotaUsage(BaseModel):
    """
    Quota usage details for a single scope/metric combination
    """ # noqa: E501
    scope: Optional[StrictStr] = Field(default=None, description="\"user\" or \"group\"")
    identifier: Optional[StrictStr] = Field(default=None, description="username or group name")
    metric: Optional[StrictStr] = Field(default=None, description="\"requests\" or \"tokens\"")
    used: Optional[StrictStr] = Field(default=None, description="amount consumed in current window")
    limit: Optional[StrictStr] = Field(default=None, description="configured limit")
    remaining: Optional[StrictStr] = Field(default=None, description="limit - used")
    unit: Optional[StrictStr] = Field(default=None, description="time window unit")
    resets_at: Optional[StrictStr] = Field(default=None, description="unix timestamp when window resets")
    __properties: ClassVar[List[str]] = ["scope", "identifier", "metric", "used", "limit", "remaining", "unit", "resets_at"]

    @field_validator('unit')
    def unit_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['RATE_LIMIT_UNIT_UNKNOWN', 'SECOND', 'MINUTE', 'HOUR', 'DAY']):
            raise ValueError("must be one of enum values ('RATE_LIMIT_UNIT_UNKNOWN', 'SECOND', 'MINUTE', 'HOUR', 'DAY')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ServingQuotaUsage from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ServingQuotaUsage from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "scope": obj.get("scope"),
            "identifier": obj.get("identifier"),
            "metric": obj.get("metric"),
            "used": obj.get("used"),
            "limit": obj.get("limit"),
            "remaining": obj.get("remaining"),
            "unit": obj.get("unit"),
            "resets_at": obj.get("resets_at")
        })
        return _obj





# coding: utf-8

"""
    Cloudera AI Inference

    CML Serving :: Install and manage CML Serving workloads.

    The version of the OpenAPI document: v1alpha1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from cloudera.ai.inference.models.serving_application_revision import ServingApplicationRevision

class TestServingApplicationRevision(unittest.TestCase):
    """ServingApplicationRevision unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ServingApplicationRevision:
        """Test ServingApplicationRevision
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ServingApplicationRevision`
        """
        model = ServingApplicationRevision()
        if include_optional:
            return ServingApplicationRevision(
                source = cloudera.ai.inference.models.serving/application_source.serving.ApplicationSource(
                    container_source = cloudera.ai.inference.models.serving/application_container_source.serving.ApplicationContainerSource(
                        url = '', 
                        environment_variables = [
                            cloudera.ai.inference.models.serving/environment_variable.serving.EnvironmentVariable(
                                name = '', 
                                value = '', )
                            ], 
                        username = '', 
                        access_token = '', ), 
                    directory_source = cloudera.ai.inference.models.serving/application_directory_source.serving.ApplicationDirectorySource(
                        url = '', 
                        entry_point = '', 
                        runtime_image = '', 
                        credentials = cloudera.ai.inference.models.serving/application_directory_source_credentials.serving.ApplicationDirectorySourceCredentials(
                            github_credentials = cloudera.ai.inference.models.serving/github_source_credentials.serving.GithubSourceCredentials(
                                username = '', 
                                ssh_key = '', 
                                access_token = '', ), 
                            s3_credentials = cloudera.ai.inference.models.serving/s3_source_credentials.serving.S3SourceCredentials(
                                access_key_id = '', 
                                secret_access_key = '', ), ), ), ),
                metadata = cloudera.ai.inference.models.serving/revision_meta.serving.RevisionMeta(
                    name = '', 
                    traffic = 56, 
                    desired_replicas = 56, 
                    actual_replicas = 56, 
                    ready = True, 
                    failed = True, 
                    generation = '', 
                    conditions = [
                        cloudera.ai.inference.models.serving/condition.serving.Condition(
                            type = '', 
                            status = '', 
                            severity = '', 
                            last_transition_time = '', 
                            reason = '', 
                            message = '', )
                        ], 
                    replica_names = [
                        ''
                        ], )
            )
        else:
            return ServingApplicationRevision(
        )
        """

    def testServingApplicationRevision(self):
        """Test ServingApplicationRevision"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Cloudera AI Inference

    CML Serving :: Install and manage CML Serving workloads.

    The version of the OpenAPI document: v1alpha1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from cloudera.ai.inference.models.serving_abs_inference_logging_config import ServingABSInferenceLoggingConfig
from cloudera.ai.inference.models.serving_data_lake_logging_config import ServingDataLakeLoggingConfig
from cloudera.ai.inference.models.serving_gcs_inference_logging_config import ServingGCSInferenceLoggingConfig
from cloudera.ai.inference.models.serving_s3_inference_logging_config import ServingS3InferenceLoggingConfig
from typing import Optional, Set
from typing_extensions import Self

class ServingInferenceLoggingConfig(BaseModel):
    """
    ServingInferenceLoggingConfig
    """ # noqa: E501
    enabled: Optional[StrictBool] = None
    explainer_s3_config: Optional[ServingS3InferenceLoggingConfig] = None
    explainer_abs_config: Optional[ServingABSInferenceLoggingConfig] = None
    explainer_gcs_config: Optional[ServingGCSInferenceLoggingConfig] = None
    explainer_datalake_config: Optional[ServingDataLakeLoggingConfig] = None
    predictor_s3_config: Optional[ServingS3InferenceLoggingConfig] = None
    predictor_abs_config: Optional[ServingABSInferenceLoggingConfig] = None
    predictor_gcs_config: Optional[ServingGCSInferenceLoggingConfig] = None
    predictor_datalake_config: Optional[ServingDataLakeLoggingConfig] = None
    transformer_s3_config: Optional[ServingS3InferenceLoggingConfig] = None
    transformer_abs_config: Optional[ServingABSInferenceLoggingConfig] = None
    transformer_gcs_config: Optional[ServingGCSInferenceLoggingConfig] = None
    transformer_datalake_config: Optional[ServingDataLakeLoggingConfig] = None
    format: Optional[StrictStr] = None
    batch_size: Optional[StrictInt] = Field(default=None, description="Number of inference records buffered into a single log object before flush.  Zero or unset means \"use the API default\" (1 for json, larger for parquet).")
    rollover_frequency: Optional[StrictStr] = Field(default=None, description="Wall-clock cadence at which a partial batch is flushed to storage even if  batch_size has not been reached. Unset means flush only on batch_size.")
    __properties: ClassVar[List[str]] = ["enabled", "explainer_s3_config", "explainer_abs_config", "explainer_gcs_config", "explainer_datalake_config", "predictor_s3_config", "predictor_abs_config", "predictor_gcs_config", "predictor_datalake_config", "transformer_s3_config", "transformer_abs_config", "transformer_gcs_config", "transformer_datalake_config", "format", "batch_size", "rollover_frequency"]

    @field_validator('format')
    def format_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['LOGGING_FORMAT_UNKNOWN', 'LOGGING_FORMAT_JSON', 'LOGGING_FORMAT_PARQUET']):
            raise ValueError("must be one of enum values ('LOGGING_FORMAT_UNKNOWN', 'LOGGING_FORMAT_JSON', 'LOGGING_FORMAT_PARQUET')")
        return value

    @field_validator('rollover_frequency')
    def rollover_frequency_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['ROLLOVER_FREQUENCY_UNKNOWN', 'ROLLOVER_FREQUENCY_FIVE_MINUTES', 'ROLLOVER_FREQUENCY_FIFTEEN_MINUTES', 'ROLLOVER_FREQUENCY_THIRTY_MINUTES', 'ROLLOVER_FREQUENCY_HOURLY', 'ROLLOVER_FREQUENCY_DAILY', 'ROLLOVER_FREQUENCY_WEEKLY']):
            raise ValueError("must be one of enum values ('ROLLOVER_FREQUENCY_UNKNOWN', 'ROLLOVER_FREQUENCY_FIVE_MINUTES', 'ROLLOVER_FREQUENCY_FIFTEEN_MINUTES', 'ROLLOVER_FREQUENCY_THIRTY_MINUTES', 'ROLLOVER_FREQUENCY_HOURLY', 'ROLLOVER_FREQUENCY_DAILY', 'ROLLOVER_FREQUENCY_WEEKLY')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ServingInferenceLoggingConfig from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of explainer_s3_config
        if self.explainer_s3_config:
            _dict['explainer_s3_config'] = self.explainer_s3_config.to_dict()
        # override the default output from pydantic by calling `to_dict()` of explainer_abs_config
        if self.explainer_abs_config:
            _dict['explainer_abs_config'] = self.explainer_abs_config.to_dict()
        # override the default output from pydantic by calling `to_dict()` of explainer_gcs_config
        if self.explainer_gcs_config:
            _dict['explainer_gcs_config'] = self.explainer_gcs_config.to_dict()
        # override the default output from pydantic by calling `to_dict()` of explainer_datalake_config
        if self.explainer_datalake_config:
            _dict['explainer_datalake_config'] = self.explainer_datalake_config.to_dict()
        # override the default output from pydantic by calling `to_dict()` of predictor_s3_config
        if self.predictor_s3_config:
            _dict['predictor_s3_config'] = self.predictor_s3_config.to_dict()
        # override the default output from pydantic by calling `to_dict()` of predictor_abs_config
        if self.predictor_abs_config:
            _dict['predictor_abs_config'] = self.predictor_abs_config.to_dict()
        # override the default output from pydantic by calling `to_dict()` of predictor_gcs_config
        if self.predictor_gcs_config:
            _dict['predictor_gcs_config'] = self.predictor_gcs_config.to_dict()
        # override the default output from pydantic by calling `to_dict()` of predictor_datalake_config
        if self.predictor_datalake_config:
            _dict['predictor_datalake_config'] = self.predictor_datalake_config.to_dict()
        # override the default output from pydantic by calling `to_dict()` of transformer_s3_config
        if self.transformer_s3_config:
            _dict['transformer_s3_config'] = self.transformer_s3_config.to_dict()
        # override the default output from pydantic by calling `to_dict()` of transformer_abs_config
        if self.transformer_abs_config:
            _dict['transformer_abs_config'] = self.transformer_abs_config.to_dict()
        # override the default output from pydantic by calling `to_dict()` of transformer_gcs_config
        if self.transformer_gcs_config:
            _dict['transformer_gcs_config'] = self.transformer_gcs_config.to_dict()
        # override the default output from pydantic by calling `to_dict()` of transformer_datalake_config
        if self.transformer_datalake_config:
            _dict['transformer_datalake_config'] = self.transformer_datalake_config.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ServingInferenceLoggingConfig from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "enabled": obj.get("enabled"),
            "explainer_s3_config": ServingS3InferenceLoggingConfig.from_dict(obj["explainer_s3_config"]) if obj.get("explainer_s3_config") is not None else None,
            "explainer_abs_config": ServingABSInferenceLoggingConfig.from_dict(obj["explainer_abs_config"]) if obj.get("explainer_abs_config") is not None else None,
            "explainer_gcs_config": ServingGCSInferenceLoggingConfig.from_dict(obj["explainer_gcs_config"]) if obj.get("explainer_gcs_config") is not None else None,
            "explainer_datalake_config": ServingDataLakeLoggingConfig.from_dict(obj["explainer_datalake_config"]) if obj.get("explainer_datalake_config") is not None else None,
            "predictor_s3_config": ServingS3InferenceLoggingConfig.from_dict(obj["predictor_s3_config"]) if obj.get("predictor_s3_config") is not None else None,
            "predictor_abs_config": ServingABSInferenceLoggingConfig.from_dict(obj["predictor_abs_config"]) if obj.get("predictor_abs_config") is not None else None,
            "predictor_gcs_config": ServingGCSInferenceLoggingConfig.from_dict(obj["predictor_gcs_config"]) if obj.get("predictor_gcs_config") is not None else None,
            "predictor_datalake_config": ServingDataLakeLoggingConfig.from_dict(obj["predictor_datalake_config"]) if obj.get("predictor_datalake_config") is not None else None,
            "transformer_s3_config": ServingS3InferenceLoggingConfig.from_dict(obj["transformer_s3_config"]) if obj.get("transformer_s3_config") is not None else None,
            "transformer_abs_config": ServingABSInferenceLoggingConfig.from_dict(obj["transformer_abs_config"]) if obj.get("transformer_abs_config") is not None else None,
            "transformer_gcs_config": ServingGCSInferenceLoggingConfig.from_dict(obj["transformer_gcs_config"]) if obj.get("transformer_gcs_config") is not None else None,
            "transformer_datalake_config": ServingDataLakeLoggingConfig.from_dict(obj["transformer_datalake_config"]) if obj.get("transformer_datalake_config") is not None else None,
            "format": obj.get("format"),
            "batch_size": obj.get("batch_size"),
            "rollover_frequency": obj.get("rollover_frequency")
        })
        return _obj





# coding: utf-8

"""
    Cloudera AI Inference

    CML Serving :: Install and manage CML Serving workloads.

    The version of the OpenAPI document: v1alpha1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class ServingAutoscalingConfig(BaseModel):
    """
    ServingAutoscalingConfig
    """ # noqa: E501
    metric: Optional[StrictStr] = Field(default=None, description="the metric that is to be watched to make autoscaling decisions.  Can be set to either RPS or Concurrency")
    target: Optional[StrictStr] = Field(default=None, description="the limit for the metric of each replica.  Each replica can only handle at most this target.  By default, the values are set at 200")
    target_utilization: Optional[StrictStr] = Field(default=None, description="a tuning of the target field to specify how \"hot\" each replica runs.  Set as a percentage, this will determine scale up sensitivitry")
    scale_to_zero_retention: Optional[StrictStr] = Field(default=None, description="tuning of how long after a scale to zero decision has been made that the pod should remain available before scaling down")
    activation_scale: Optional[StrictStr] = Field(default=None, description="the number of replicas that should be created when scaling up from zero")
    scale_down_delay: Optional[StrictStr] = Field(default=None, description="how long to wait before a scale down decision is made")
    panic_window_percentage: Optional[StrictStr] = Field(default=None, description="the size of the panic window as a percentage of the stable window")
    panic_threshold: Optional[StrictStr] = Field(default=None, description="the amount of traffic that each replica must be receiving before entering into panic mode: exceeding all limits and scaling to deal with short, high bursts of traffic")
    stable_window: Optional[StrictStr] = Field(default=None, description="the interval in which metrics are being scraped and processed to determine autoscaling decisions")
    __properties: ClassVar[List[str]] = ["metric", "target", "target_utilization", "scale_to_zero_retention", "activation_scale", "scale_down_delay", "panic_window_percentage", "panic_threshold", "stable_window"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ServingAutoscalingConfig from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ServingAutoscalingConfig from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "metric": obj.get("metric"),
            "target": obj.get("target"),
            "target_utilization": obj.get("target_utilization"),
            "scale_to_zero_retention": obj.get("scale_to_zero_retention"),
            "activation_scale": obj.get("activation_scale"),
            "scale_down_delay": obj.get("scale_down_delay"),
            "panic_window_percentage": obj.get("panic_window_percentage"),
            "panic_threshold": obj.get("panic_threshold"),
            "stable_window": obj.get("stable_window")
        })
        return _obj





# coding: utf-8

"""
    Cloudera AI Inference

    CML Serving :: Install and manage CML Serving workloads.

    The version of the OpenAPI document: v1alpha1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from cloudera.ai.inference.models.serving_describe_endpoint_response import ServingDescribeEndpointResponse

class TestServingDescribeEndpointResponse(unittest.TestCase):
    """ServingDescribeEndpointResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ServingDescribeEndpointResponse:
        """Test ServingDescribeEndpointResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ServingDescribeEndpointResponse`
        """
        model = ServingDescribeEndpointResponse()
        if include_optional:
            return ServingDescribeEndpointResponse(
                namespace = '',
                name = '',
                url = '',
                conditions = [
                    cloudera.ai.inference.models.serving/condition.serving.Condition(
                        type = '', 
                        status = '', 
                        severity = '', 
                        last_transition_time = '', 
                        reason = '', 
                        message = '', )
                    ],
                status = cloudera.ai.inference.models.serving/model_status.serving.ModelStatus(
                    failed_copies = 56, 
                    total_copies = 56, 
                    active_model_state = '', 
                    target_model_state = '', 
                    transition_status = '', ),
                observed_generation = 56,
                replica_count = 56,
                created_by = '',
                description = '',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                resources = cloudera.ai.inference.models.serving/resources.serving.Resources(
                    req_cpu = '', 
                    req_memory = '', 
                    num_gpus = '', 
                    gpu_resource_name = '', ),
                revisions = [
                    cloudera.ai.inference.models.serving/model_revision.serving.ModelRevision(
                        source = cloudera.ai.inference.models.serving/model_source.serving.ModelSource(
                            registry_source = cloudera.ai.inference.models.serving/registry_source.serving.RegistrySource(
                                model_id = '', 
                                version = 56, 
                                registry_id = '', ), 
                            third_party_source = cloudera.ai.inference.models.serving/third_party_source.serving.ThirdPartySource(
                                url = '', 
                                model = '', 
                                provider_type = 'THIRD_PARTY_PROVIDER_UNSPECIFIED', 
                                api_key = '', 
                                aws_credentials = null, 
                                gcp_credentials = null, 
                                api_version = '', 
                                path_prefix = '', ), ), 
                        metadata = cloudera.ai.inference.models.serving/revision_meta.serving.RevisionMeta(
                            name = '', 
                            traffic = 56, 
                            desired_replicas = 56, 
                            actual_replicas = 56, 
                            ready = True, 
                            failed = True, 
                            generation = '', 
                            conditions = [
                                cloudera.ai.inference.models.serving/condition.serving.Condition(
                                    type = '', 
                                    status = '', 
                                    severity = '', 
                                    last_transition_time = '', 
                                    reason = '', 
                                    message = '', )
                                ], 
                            replica_names = [
                                ''
                                ], ), )
                    ],
                autoscaling = cloudera.ai.inference.models.serving/autoscaling.serving.Autoscaling(
                    min_replicas = '', 
                    max_replicas = '', 
                    autoscaling_config = null, ),
                relevant_revisions = cloudera.ai.inference.models.serving/relevant_revisions_meta.serving.RelevantRevisionsMeta(
                    latest_created_revision = '', 
                    latest_ready_revision = '', 
                    latest_rolledout_revision = '', 
                    previous_rolledout_revision = '', ),
                model_name = '',
                traffic = cloudera.ai.inference.models.serving/traffic.serving.Traffic(
                    current_revision_traffic = '', 
                    previous_revision_traffic = '', ),
                api_standard = '',
                has_chat_template = True,
                metric_format = '',
                task = '',
                instance_type = '',
                optimization_profile = cloudera.ai.inference.models.serving/optimization_profile.serving.OptimizationProfile(
                    gpu = '', 
                    gpu_device = '', 
                    gpu_count = '', 
                    precision = '', 
                    release = '', 
                    embed_config = cloudera.ai.inference.models.serving/embed_config.serving.EmbedConfig(
                        dimension = 56, 
                        max_tokens = 56, ), 
                    text_gen_config = cloudera.ai.inference.models.serving/text_generation_config.serving.TextGenerationConfig(
                        llm_engine = '', 
                        max_image_size = '', 
                        profile = '', ), 
                    rank_config = cloudera.ai.inference.models.serving/rank_config.serving.RankConfig(
                        max_tokens = 56, 
                        max_passages = 56, ), ),
                crn = '',
                inference_logging_config = cloudera.ai.inference.models.serving/inference_logging_config.serving.InferenceLoggingConfig(
                    enabled = True, 
                    explainer_s3_config = cloudera.ai.inference.models.serving/s3_inference_logging_config.serving.S3InferenceLoggingConfig(
                        bucket_url = '', 
                        access_key_id = '', 
                        secret_access_key = '', 
                        region = '', ), 
                    explainer_abs_config = cloudera.ai.inference.models.serving/abs_inference_logging_config.serving.ABSInferenceLoggingConfig(
                        bucket_url = '', 
                        client_id = '', 
                        client_secret = '', 
                        tenant_id = '', 
                        subscription_id = '', 
                        access_token = '', 
                        access_token_expiration_seconds = 56, 
                        service_url = '', ), 
                    explainer_gcs_config = cloudera.ai.inference.models.serving/gcs_inference_logging_config.serving.GCSInferenceLoggingConfig(
                        bucket_url = '', 
                        key_file = '', ), 
                    explainer_datalake_config = cloudera.ai.inference.models.serving/data_lake_logging_config.serving.DataLakeLoggingConfig(
                        datalake_crn = '', 
                        path = '', 
                        resolved_storage_url = '', ), 
                    predictor_s3_config = cloudera.ai.inference.models.serving/s3_inference_logging_config.serving.S3InferenceLoggingConfig(
                        bucket_url = '', 
                        access_key_id = '', 
                        secret_access_key = '', 
                        region = '', ), 
                    predictor_abs_config = cloudera.ai.inference.models.serving/abs_inference_logging_config.serving.ABSInferenceLoggingConfig(
                        bucket_url = '', 
                        client_id = '', 
                        client_secret = '', 
                        tenant_id = '', 
                        subscription_id = '', 
                        access_token = '', 
                        access_token_expiration_seconds = 56, 
                        service_url = '', ), 
                    predictor_gcs_config = cloudera.ai.inference.models.serving/gcs_inference_logging_config.serving.GCSInferenceLoggingConfig(
                        bucket_url = '', 
                        key_file = '', ), 
                    predictor_datalake_config = cloudera.ai.inference.models.serving/data_lake_logging_config.serving.DataLakeLoggingConfig(
                        datalake_crn = '', 
                        path = '', 
                        resolved_storage_url = '', ), 
                    transformer_s3_config = , 
                    transformer_abs_config = , 
                    transformer_gcs_config = , 
                    transformer_datalake_config = , 
                    format = 'LOGGING_FORMAT_UNKNOWN', 
                    batch_size = 56, 
                    rollover_frequency = 'ROLLOVER_FREQUENCY_UNKNOWN', ),
                runtime_info = cloudera.ai.inference.models.serving/runtime_info.serving.RuntimeInfo(
                    display_name = '', 
                    version = '', 
                    image_identifier = '', 
                    vllm_version = '', 
                    transformers_library_version = '', 
                    latest_version = True, 
                    runtime_name = '', ),
                vllm_args = '',
                deployment_mode = 'DEPLOYMENT_MODE_UNKNOWN',
                environment_variables = [
                    cloudera.ai.inference.models.serving/environment_variable.serving.EnvironmentVariable(
                        name = '', 
                        value = '', )
                    ],
                gpu_type = '',
                tags = [
                    cloudera.ai.inference.models.serving/label.serving.Label(
                        key = '', 
                        value = '', )
                    ],
                rate_limit = cloudera.ai.inference.models.serving/rate_limit_config.serving.RateLimitConfig(
                    request_rate = null, 
                    token_budget = null, ),
                state = ''
            )
        else:
            return ServingDescribeEndpointResponse(
        )
        """

    def testServingDescribeEndpointResponse(self):
        """Test ServingDescribeEndpointResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
